<?php

namespace App\Http\Controllers;

use App\Models\BusinessSettings;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\File;

class AdminController extends Controller
{
    public function AdminAPI2Fetch(Request $request)
    {
        $baseUrl = 'https://gamemonetize.com/feed.php?format=0';
        // Get parameters from the request
        $num = $request->input('num', 20); // Default to 20 if not provided
        $category = $request->input('category');
        $platform = $request->input('platform');
        $links = $request->input('links');
        $name = $request->input('name');

        // Build the query string
        $queryString = "&num=$num&page=1"; // Start with mandatory num and page

        if (!empty($category)) {
            $queryString .= "&category=$category";
        }
        if (!empty($platform)) {
            $queryString .= "&platform=$platform";
        }
        if (!empty($links)) {
            $queryString .= "&links=$links";
        }
        if (!empty($name)) {
            $queryString .= "&name=" . urlencode($name); // URL encode the name
        }

        // Final URL
        $apiUrl = $baseUrl . $queryString;

        // Make the API request
        $response = Http::get($apiUrl);

        // Decode the response (assuming the response is JSON)
        $games = json_decode($response->getBody()->getContents(), true);

        // Return the games in a JSON response to the frontend
        return response()->json(['games' => $games]);
    }

    public function FeatureActivation(){
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        return view('backend.features.index', compact('settings'));
    }

    public function updateForceHttps(Request $request)
    {
        $envPath = base_path('.env');

        if (file_exists($envPath)) {
            $envContent = file_get_contents($envPath);
            if (strpos($envContent, 'FORCE_HTTPS=on') !== false) {
                $newContent = str_replace('FORCE_HTTPS=on', 'FORCE_HTTPS=off', $envContent);
            } else {
                $newContent = str_replace('FORCE_HTTPS=off', 'FORCE_HTTPS=on', $envContent);
            }
            if (file_put_contents($envPath, $newContent) !== false) {
                return response()->json(['message' => 'FORCE_HTTPS toggled successfully']);
            } else {
                return response()->json(['error' => 'Failed to write to .env file'], 500);
            }
        }

        return response()->json(['error' => '.env file not found'], 404);
    }

    public function toggleLoginSetting(Request $request)
    {
        logger('Received data:', $request->all()); // Log incoming data for debugging

        $request->validate([
            'key' => 'required|string|in:facebook_login,google_login,twitter_login,apple_login',
            'value' => 'required|boolean',
        ]);

        $setting = BusinessSettings::updateOrCreate(
            ['key' => $request->key],
            ['value' => $request->value]
        );

        return response()->json([
            'success' => true,
            'message' => 'Setting updated successfully.',
            'setting' => $setting,
        ]);
    }


    public function updateSocialSettings(Request $request)
    {
        $request->validate([
            'google_client_id' => 'nullable|string',
            'google_client_secret' => 'nullable|string',
            'facebook_client_id' => 'nullable|string',
            'facebook_client_secret' => 'nullable|string',
            'twitter_client_id' => 'nullable|string',
            'twitter_client_secret' => 'nullable|string',
        ]);

        $envPath = base_path('.env');

        if (File::exists($envPath)) {
            // Read .env file
            $env = File::get($envPath);

            // Replace or add the keys
            $env = $this->setEnvValue($env, 'GOOGLE_CLIENT_ID', $request->input('google_client_id'));
            $env = $this->setEnvValue($env, 'GOOGLE_CLIENT_SECRET', $request->input('google_client_secret'));
            $env = $this->setEnvValue($env, 'FACEBOOK_CLIENT_ID', $request->input('facebook_client_id'));
            $env = $this->setEnvValue($env, 'FACEBOOK_CLIENT_SECRET', $request->input('facebook_client_secret'));
            $env = $this->setEnvValue($env, 'TWITTER_CLIENT_ID', $request->input('twitter_client_id'));
            $env = $this->setEnvValue($env, 'TWITTER_CLIENT_SECRET', $request->input('twitter_client_secret'));

            // Save the .env file
            File::put($envPath, $env);
        }

        return redirect()->back()->with('success', 'Social login settings updated successfully.');
    }

    /**
     * Set or replace an environment variable in the .env content.
     *
     * @param string $env
     * @param string $key
     * @param string|null $value
     * @return string
     */
    protected function setEnvValue($env, $key, $value)
    {
        $pattern = "/^$key=.*$/m";

        if (preg_match($pattern, $env)) {
            // Replace existing value
            return preg_replace($pattern, "$key=\"$value\"", $env);
        }

        // Add new key
        return $env . PHP_EOL . "$key=\"$value\"";
    }

}
