<?php

namespace App\Http\Controllers;

use App\Models\BlogCategory;
use Illuminate\Http\Request;
use Illuminate\Support\Str;

class BlogCategoryController extends Controller
{
    public function blogCategories(){
        $blogCategories = BlogCategory::orderBy('id', 'DESC')->paginate(15);
        return view('backend.blog-category.index', compact('blogCategories'));
    }

    public function create(){
        $parentCategory = BlogCategory::where('parent_id', null)->where('status', 1)->get();
        return view('backend.blog-category.create', compact('parentCategory'));
    }

    public function store(Request $request){
        // Create a new Category instance
        $category = new BlogCategory();
        $category->name = $request['name'];
        $category->slug = Str::slug($request['name']);
        $category->description = $request['description'] ?? null;
        $category->parent_id = $request['parent_id'] ?? null;

        // Save the category
        $category->save();

        // Redirect back with a success message
        return redirect()->route('admin.blog.categories')->with('success', 'Category created successfully.');
    }

    public function toggleStatus(Request $request){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $category = BlogCategory::findOrFail($request->id);
            $category->status = $request->is_active;
            $category->save();

            return response()->json(['success' => true]);
        }
    }

    public function edit($id){
        $category = BlogCategory::findOrFail($id);
        $parentCategory = BlogCategory::where('parent_id', null)->where('status', 1)->get();
        return view('backend.blog-category.edit', compact('category', 'parentCategory'));
    }

    public function update(Request $request){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $category = BlogCategory::findOrFail($request->id);
            $category->name = $request['name'];
            $category->slug = Str::slug($request['name']);
            $category->description = $request['description'] ?? null;
            $category->parent_id = $request['parent_id'] ?? null;

            // Save the category
            $category->save();

            // Redirect back with a success message
            return redirect()->route('admin.blog.categories')->with('success', 'Category updated successfully.');
        }
    }

    public function delete($id){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $category = BlogCategory::findOrFail($id);
            $category->delete();
            return redirect()->route('admin.blog.categories')->with('success', 'Category deleted successfully.');
        }
    }
}
