<?php

namespace App\Http\Controllers;

use App\Models\BlogCategory;
use App\Models\BlogPost;
use App\Models\BusinessSettings;
use App\Models\Category;
use App\Models\Game;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use Illuminate\Container\Attributes\Auth;

class BlogPostController extends Controller
{

    public function blogpost($slug)
    {
        $blogpost = BlogPost::where('slug', $slug)->firstOrFail();
        $recentGames = Game::where('status', 1)->orderBy('id', 'DESC')->limit(30)->get();
        $mostplayedGames = Game::where('status', 1)->orderBy('views', 'DESC')->limit(10)->get();
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        if($settings['theme'] == 'playverse'){
            return view('frontend.blogs.index', compact('blogpost', 'recentGames', 'mostplayedGames', 'settings'));
        }elseif($settings['theme'] == 'gamehive'){
            $hivecategories = Category::where('is_active', 1)->get();
            return view('frontend.blogs.index-gamehive', compact('blogpost', 'recentGames', 'mostplayedGames', 'settings', 'hivecategories'));
        }else{
            return redirect()->route('home');
        }

    }

    public function Blogs()
    {
        $blogposts = BlogPost::where('status', 'published')->orderBy('id', 'desc')->paginate(15);
        $recentGames = Game::where('status', 1)->orderBy('id', 'DESC')->limit(30)->get();
        $mostplayedGames = Game::where('status', 1)->orderBy('views', 'DESC')->limit(10)->get();
        $settings = BusinessSettings::pluck('value', 'key')->toArray();
        if($settings['theme'] == 'playverse'){
            return view('frontend.blogs.all', compact('blogposts', 'recentGames', 'mostplayedGames', 'settings'));
        }elseif($settings['theme'] == 'gamehive'){
            $hivecategories = Category::where('is_active', 1)->get();
            return view('frontend.blogs.all-gamehive', compact('blogposts', 'recentGames', 'mostplayedGames', 'settings', 'hivecategories'));
        }else{
            return redirect()->route('home');
        }
    }

    public function blogPosts() {
        $blogposts = BlogPost::orderBy('id', 'desc')->paginate(15);
        return view('backend.blog-post.index', compact('blogposts'));
    }

    public function create() {
        $blogcategory = BlogCategory::where('status', 1)->where('parent_id', null)->get();
        return view('backend.blog-post.create', compact('blogcategory'));
    }

    public function store(Request $request)
    {
        // Validate form inputs
        $request->validate([
            'name' => 'required|string|max:255',

        ]);

        // Initialize variables for storing data
        $imageName = null;

        // Handle file upload for the image if provided
        if ($request->hasFile('image')) {
            $imageName = 'post-' . time() . '.' . $request->image->extension();
            $request->image->move(public_path('images/posts'), $imageName); // Move to 'public/images/posts'
        }

        // Process the tags (keywords) into a JSON format
        $keywords = [];
        if ($request->filled('tags')) {
            $keywords = explode(',', $request->tags); // Split the comma-separated string into an array
            $keywords = array_map('trim', $keywords); // Trim spaces around the tags
        }

        // Store the new blog post in the database
        $blogPost = new BlogPost();
        $blogPost->title = $request->name;
        $blogPost->slug = Str::slug($request->name, '-');
        $blogPost->content = $request->description;
        $blogPost->category_id = $request->category_id;
        $blogPost->featured_image = $imageName; // Set the image if uploaded, otherwise null
        $blogPost->meta_title = $request->meta_title;
        $blogPost->meta_description = $request->meta_description;
        $blogPost->meta_keywords = json_encode($keywords); // Store keywords as JSON
        $blogPost->status = $request->status == '1' ? 'published' : 'draft'; // Set status based on input
        $blogPost->author_id = auth()->id(); // Assuming the user is authenticated and the author is the logged-in user
        $blogPost->published_at = $request->status == '1' ? now() : null; // If status is published, set the publish date
        $blogPost->views_count = 0; // Default to 0 views
        $blogPost->save();

        // Redirect with success message
        return redirect()->route('admin.blog.posts')->with('success', 'Blog post created successfully!');
    }

    public function toggleStatus(Request $request){
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $blog = BlogPost::findOrFail($request->id);
            $blog->status = $request->is_active;
            $blog->save();
            return response()->json(['success' => true]);
        }
    }

    public function edit($id)
    {
        $blogpost = BlogPost::findOrFail($id);
        $blogcategory = BlogCategory::where('status', 1)->where('parent_id', null)->get();
        return view('backend.blog-post.edit', compact('blogpost', 'blogcategory'));
    }

    public function update(Request $request)
    {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $request->validate([
                'name' => 'required|string|max:255',
            ]);

            $blogPost = BlogPost::findOrFail($request->id);

            // Handle file upload for the image if provided
            if ($request->hasFile('image')) {
                // Delete the old image if it exists
                if ($blogPost->featured_image) {
                    Storage::disk('public')->delete('images/posts/' . $blogPost->featured_image);
                }

                $imageName = 'post-' . time() . '.' . $request->image->extension();
                $request->image->move(public_path('images/posts'), $imageName);
                $blogPost->featured_image = $imageName;
            }

            // Process the tags (keywords) into a JSON format
            $keywords = [];
            if ($request->filled('tags')) {
                $keywords = explode(', ', $request->tags);
                $keywords = array_map('trim', $keywords);
            }

            $blogPost->title = $request->name;
            $blogPost->slug = Str::slug($request->name, '-');
            $blogPost->content = $request->description;
            $blogPost->category_id = $request->category_id;
            $blogPost->meta_title = $request->meta_title;
            $blogPost->meta_description = $request->meta_description;
            $blogPost->meta_keywords = json_encode($keywords);
            $blogPost->status = $request->status == '1' ? 'published' : 'draft';
            $blogPost->author_id = auth()->id();
            $blogPost->published_at = $request->status == '1' ? now() : null;
            $blogPost->save();

            return redirect()->route('admin.blog.posts')->with('success', 'Blog post updated successfully!');
        }
    }

    public function delete($id) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', 'This action is disabled in demo mode.');
        } else {
            $blogpost = BlogPost::findOrFail($id);
            $blogpost->delete();
            return redirect()->route('admin.blog.posts')->with('success', 'Blog post deleted successfully!');
        }
    }
}
