<?php

namespace App\Http\Controllers;

use App\Models\Pages;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use App\Models\Game;

class PagesController extends Controller
{
    public function pages() {
        $pages = Pages::orderBy('id', 'desc')->paginate(15);
        return view('backend.pages.index', compact('pages'));
    }

    public function create() {
        return view('backend.pages.create');
    }

    public function UserPages($slug){
        $recentGames = Game::where('status', 1)->orderBy('id', 'DESC')->limit(30)->get();
        $mostplayedGames = Game::where('status', 1)->orderBy('views', 'DESC')->limit(10)->get();
        $page = Pages::where('slug', $slug)->where('status', 'published')->firstOrFail();

        // Return a view with the page content
        return view('frontend.pages.index', compact('page', 'recentGames', 'mostplayedGames'));
    }

    public function store(Request $request)
    {
        // Validate the form data
        $request->validate([
            'name' => 'required|string|max:255',
            'description' => 'required',
            'image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048', // Validate image, but it's optional
        ]);

        // Initialize the image name to null
        $imageName = null;

        // Handle the image upload if a new image is provided
        if ($request->hasFile('image')) {
            // Generate a new image name and move the file
            $imageName = 'page' . time() . '.' . $request->image->extension();
            $request->image->move(public_path('images/pages'), $imageName);
        }

        // Process the tags (keywords) into a JSON format
        $keywords = [];
        if ($request->filled('tags')) {
            // Split the comma-separated string into an array
            $keywords = explode(',', $request->tags);
            // Trim spaces around keywords and store as JSON
            $keywords = array_map('trim', $keywords);
        }

        // Create a new Page
        $page = new Pages();
        $page->title = $request->name;
        $page->content = $request->description;
        $page->featured_image = $imageName; // Set image if uploaded, else null
        $page->status = $request->status == '1' ? 'published' : 'draft';
        $page->slug = Str::slug($request->name, '-');
        $page->meta_title = $request->meta_title;
        $page->meta_description = $request->meta_description;
        $page->meta_keywords = json_encode($keywords); // Store keywords as JSON
        $page->save();

        // Redirect with success message
        return redirect()->route('admin.pages')->with('success', 'Page created successfully!');
    }


    public function edit($id) {
        $page = Pages::findOrFail($id);
        return view('backend.pages.edit', compact('page'));
    }

    public function update(Request $request) {
        // Validate the form data
        $request->validate([
            'name' => 'required|string|max:255',
        ]);

        // Find the existing page record
        $page = Pages::findOrFail($request->id);

        // Handle the image upload if a new image is provided
        if ($request->hasFile('image')) {
            // Generate a new image name and move the file
            $imageName = 'page' . time() . '.' . $request->image->extension();
            $request->image->move(public_path('images/pages'), $imageName);
            // Assign the new image name to the page
            $page->featured_image = $imageName;
        }

        // Process the tags (keywords) into a JSON format
        $keywords = [];
        if ($request->filled('tags')) {
            // Split the comma-separated string into an array
            $keywords = explode(',', $request->tags);
            // Trim spaces around keywords and store as JSON
            $keywords = array_map('trim', $keywords);
        }

        // Update other fields
        $page->title = $request->name;
        $page->content = $request->description;
        $page->status = $request->status == '1' ? 'published' : 'draft';
        $page->slug = $request->slug;
        $page->meta_title = $request->meta_title;
        $page->meta_description = $request->meta_description;
        $page->meta_keywords = json_encode($keywords); // Store keywords as JSON

        // Save the updated record
        $page->save();

        // Redirect with success message
        return redirect()->route('admin.pages')->with('success', 'Page updated successfully!');
    }

    public function toggleStatus(Request $request) {

        if(env('DEMO_MODE') == 'on'){
            return redirect()->back()->with('error', 'You can\'t perform this action in Demo Mode.');
        } {
            $category = Pages::findOrFail($request->id);
            $category->status = $request->is_active;
            $category->save();

            return response()->json(['success' => true]);
        }

    }

    public function delete($id) {
        if (env('DEMO_MODE') == 'on') {
            return redirect()->back()->with('error', "You can't perform this action in Demo Mode.");
        } else {
            $page = Pages::findOrFail($id);
            $page->delete();
            return redirect()->back()->with('success', 'Page deleted successfully!');
        }

    }
}
