<?php

namespace App\Http\Controllers;

use App\Models\BlogPost;
use App\Models\Category;
use Illuminate\Http\Request;
use Spatie\Sitemap\Sitemap;
use Spatie\Sitemap\Tags\Url;
use Carbon\Carbon;
use App\Models\Game;
use App\Models\Pages;

class SitemapController extends Controller
{
    public function index()
    {
        // Create a new sitemap instance
        $sitemap = Sitemap::create();

        // Add home page URL to the sitemap
        $sitemap->add(Url::create('/')
            ->setLastModificationDate(Carbon::yesterday())
            ->setChangeFrequency(Url::CHANGE_FREQUENCY_DAILY)
            ->setPriority(1.0));

        // Add all games URLs to the sitemap
        $games = Game::all(); // Get all games from the database
        foreach ($games as $game) {
            $sitemap->add(Url::create("/game/{$game->slug}")
                ->setLastModificationDate($game->updated_at)
                ->setChangeFrequency(Url::CHANGE_FREQUENCY_WEEKLY)
                ->setPriority(0.8));
        }

        // Add all categories URLs to the sitemap
        $categories = Category::all(); // Get all categories from the database
        foreach ($categories as $category) {
            $sitemap->add(Url::create("/category/{$category->slug}")
                ->setLastModificationDate($category->updated_at)
                ->setChangeFrequency(Url::CHANGE_FREQUENCY_WEEKLY)
                ->setPriority(0.7));
        }

        // Add all blog posts URLs to the sitemap
        $blogPosts = BlogPost::all(); // Get all blog posts from the database
        foreach ($blogPosts as $post) {
            $sitemap->add(Url::create("/blog/{$post->slug}")
                ->setLastModificationDate($post->updated_at)
                ->setChangeFrequency(Url::CHANGE_FREQUENCY_DAILY)
                ->setPriority(0.9));
        }

        // Add all static pages URLs to the sitemap
        $pages = Pages::all(); // Get all pages from the database
        foreach ($pages as $page) {
            $sitemap->add(Url::create("/{$page->slug}")
                ->setLastModificationDate($page->updated_at)
                ->setChangeFrequency(Url::CHANGE_FREQUENCY_MONTHLY)
                ->setPriority(0.6));
        }

        // Return the generated sitemap in XML format
        return $sitemap->toResponse(request());
    }
}
