<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Cookie;

class Game extends Model
{
    use HasFactory;

    protected $fillable = [
        'category_id',
        'name',
        'description',
        'image',
        'banner',
        'slug',
        'game_url',
        'views',
        'plays',
        'status',
        'featured',
        'average_rating',
        'number_of_reviews',
        'tags',
        'published_at',
        'developer_name',
        'developer_url',
        'meta_title',
        'meta_description',
    ];

    public function category()
    {
        return $this->belongsTo(Category::class);
    }

    public function reactions()
    {
        return $this->hasMany(GameReaction::class);
    }

    public function comments()
    {
        return $this->hasMany(Comment::class);
    }

    protected $appends = ['name', 'description'];

    public function translations()
    {
        return $this->hasMany(GameTranslation::class);
    }

    public function getNameAttribute()
    {
        $defaultLang = BusinessSettings::where('key', 'default_language')->first()->value;
        // Check if the request is from the admin panel
        if (request()->is('admin/*')) {
            return $this->attributes['name']; // Return original name in admin panel
        }

        // Otherwise, return the translated name on the frontend
        $locale = Cookie::get('app_locale', session('locale', $defaultLang)); // Default to 'en' if no locale is set
        $translation = $this->translations()->where('locale', $locale)->first();

        // If translation exists, return it, otherwise fallback to English
        if ($translation) {
            return $translation->name;
        } else {
            $defaultTranslation = $this->translations()->where('locale', 'en')->first();
            return $defaultTranslation ? $defaultTranslation->name : $this->attributes['name']; // Fallback to default name
        }
    }

    public function getDescriptionAttribute()
    {
        $defaultLang = BusinessSettings::where('key', 'default_language')->first()->value;
        // Check if the request is from the admin panel
        if (request()->is('admin/*')) {
            return $this->attributes['description']; // Return original description in admin panel
        }

        // Otherwise, return the translated description on the frontend
        $locale = Cookie::get('app_locale', session('locale', $defaultLang)); // Default to 'en' if no locale is set
        $translation = $this->translations()->where('locale', $locale)->first();

        // If translation exists, return it, otherwise fallback to English
        if ($translation) {
            return $translation->description;
        } else {
            $defaultTranslation = $this->translations()->where('locale', 'en')->first();
            return $defaultTranslation ? $defaultTranslation->description : $this->attributes['description']; // Fallback to default description
        }
    }
}
