@extends('backend.layout')
@section('content')
<div class="content-header">
    <div class="container-fluid">
        <div class="row mb-2">
            <div class="col-sm-6">
                <h1 class="m-0">Add New Game</h1>
            </div><!-- /.col -->
        </div><!-- /.row -->
    </div><!-- /.container-fluid -->
</div>
<!-- /.content-header -->

<!-- Main content -->
<section class="content">
    <div class="container-fluid">
        <!-- Info boxes -->
        <form action="{{ route('admin.games.update') }}" method="POST" enctype="multipart/form-data">
            @csrf

            <input type="hidden" name="id" id="id" value="{{$game->id}}">

            <div class="row">
                <!-- left column -->
                <div class="col-md-8">
                    <!-- general form elements -->
                    <div class="card card-primary">

                        <div class="card-body">
                            <!-- Game Name field -->
                            <div class="form-group">
                                <label for="name">Game Name</label>
                                <input type="text" class="form-control" id="name" name="name" value="{{ $game->name }}" placeholder="Enter Game Name" required>
                            </div>

                            <!-- Category field -->
                            <div class="form-group">
                                <label for="category_id">Category</label>
                                <select class="form-control" name="category_id" id="category_id" required>
                                    <option value="">Select Category</option>
                                    @foreach ($categories as $category)
                                        <option value="{{ $category->id }}" @if($category->id == $game->category_id) selected @endif>{{ $category->name }}</option>
                                    @endforeach
                                </select>
                            </div>

                            <!-- Description field -->
                            <div class="form-group">
                                <label for="description">Description</label>
                                <textarea class="form-control" id="description" name="description" placeholder="Enter Game Description" rows="4" required>{{ $game->description }}</textarea>
                            </div>

                            <!-- Game URL field -->
                            <div class="form-group">
                                <label for="game_url">Game URL</label>
                                <input type="text" class="form-control" id="game_url" name="game_url" value="{{ $game->game_url }}" placeholder="Enter Game URL" required>
                            </div>

                            <!-- Meta Title field -->
                            <div class="form-group">
                                <label for="meta_title">Meta Title (Optional)</label>
                                <input type="text" class="form-control" id="meta_title" name="meta_title" value="{{ $game->meta_title }}" placeholder="Enter Meta Title">
                            </div>

                            <!-- Meta Description field -->
                            <div class="form-group">
                                <label for="meta_description">Meta Description (Optional)</label>
                                <textarea class="form-control" id="meta_description" name="meta_description" placeholder="Enter Meta Description" rows="3">{{ $game->meta_description }}</textarea>
                            </div>

                            <h1 class="card-title text-center">Translations</h1><hr><br>

                            <!-- Language Tabs -->
                            <ul class="nav nav-tabs" id="languageTabs" role="tablist">
                                <li class="nav-item">
                                    <a class="nav-link active" id="english-tab" data-toggle="tab" href="#english" role="tab" aria-controls="english" aria-selected="true">English</a>
                                </li>
                                @foreach ($languages as $language)
                                    @if ($language->code !== "en")
                                        <li class="nav-item">
                                            <a class="nav-link" id="{{ $language->code }}-tab" data-toggle="tab" href="#{{ $language->name }}" role="tab" aria-controls="{{ $language->name }}" aria-selected="false">{{ $language->name }}</a>
                                        </li>
                                    @endif
                                @endforeach
                            </ul>

                            <div class="tab-content mt-3" id="languageTabsContent">
                                <div class="tab-pane fade show active" id="english" role="tabpanel" aria-labelledby="english-tab">
                                    <!-- Category Name (English) -->
                                    <div class="form-group">
                                        <label for="name_en">Category Name (English)</label>
                                        <input type="text" class="form-control" name="translations[en][name]" id="name_en" value="{{ $game->name }}" placeholder="Enter Category Name in English">
                                        <button type="button" class="btn btn-info mt-2 translateBtn" data-key="{{ $category->name }}" data-lang="{{ $language->code }}">Translate</button>
                                    </div>
                                    <!-- Category Description (English) -->
                                    <div class="form-group">
                                        <label for="description_en">Description (English)</label>
                                        <textarea class="form-control" name="translations[en][description]" id="description_en" rows="4" placeholder="Enter Description in English">{{ $game->description }}</textarea>
                                        <button type="button" class="btn btn-info mt-2 DesctranslateBtn" data-key="{{ old('description', $category->description) }}" data-lang="{{ $language->code }}">Translate</button>
                                    </div>
                                </div>

                                @foreach ($languages as $language)
                                    @if ($language->code !== 'en')
                                        <div class="tab-pane fade" id="{{ $language->name }}" role="tabpanel" aria-labelledby="{{ $language->code }}-tab">
                                            <!-- Category Name (Translated) -->
                                            <div class="form-group">
                                                <label for="name_{{ $language->code }}">Category Name ({{ $language->name }})</label>
                                                <input type="text" class="form-control" name="translations[{{ $language->code }}][name]"
                                                       id="name_{{ $language->code }}"
                                                       value="{{ old('translations.' . $language->code . '.name', $translations[$language->code]->name ?? '') }}"
                                                       placeholder="Enter Category Name in {{ $language->name }}">
                                                <button type="button" class="btn btn-info mt-2 translateBtn" data-key="{{ $game->name }}" data-lang="{{ $language->code }}">Translate</button>
                                            </div>
                                            <!-- Category Description (Translated) -->
                                            <div class="form-group">
                                                <label for="description_{{ $language->code }}">Description ({{ $language->name }})</label>
                                                <textarea class="form-control" name="translations[{{ $language->code }}][description]"
                                                          id="description_{{ $language->code }}" rows="4"
                                                          placeholder="Enter Description in {{ $language->name }}">
                                                    {{ old('translations.' . $language->code . '.description', $translations[$language->code]->description ?? '') }}
                                                </textarea>
                                                <button type="button" class="btn btn-info mt-2 DesctranslateBtn" data-key="{{ $game->description }}" data-lang="{{ $language->code }}">Translate</button>
                                            </div>
                                        </div>
                                    @endif
                                @endforeach
                            </div>



                        </div>

                    </div>
                    <!-- /.card -->
                </div>

                <div class="col-md-4">
                    <!-- general form elements -->
                    <div class="card card-primary">
                        <div class="card-body">
                            <!-- Image Drag-and-Drop field -->
                            <div class="form-group">
                                <label for="image">Game Image</label>
                                <div id="image-drop-area" class="drop-area">
                                    <p>Drag & drop an image here or click to select a file</p>
                                    <img id="image-preview" src="{{ asset('images/games/icons/' . $game->image) }}" alt="Image Preview" style="max-width: 100%; height: auto; margin-top: 10px;">
                                    <input type="file" class="form-control-file" id="image" name="image" accept="image/*"hidden>
                                </div>
                            </div>

                            <!-- Banner Drag-and-Drop field -->
                            <div class="form-group">
                                <label for="banner">Game Banner (Optional)</label>
                                <div id="banner-drop-area" class="drop-area">
                                    <p>Drag & drop a banner here or click to select a file</p>
                                    <img id="banner-preview" src="{{ asset('images/games/banner/' . $game->banner) }}" alt="Banner Preview" style="max-width: 100%; height: auto; margin-top: 10px;">
                                    <input type="file" class="form-control-file" id="banner" name="banner" accept="image/*" hidden>
                                </div>
                            </div>

                            <!-- Tags field -->
                            <div class="form-group">
                                <label for="tags">Tags (Optional)</label>
                                <input type="text" class="form-control" id="tags" name="tags" value="{{ $game->tags }}" placeholder="Enter Tags (comma separated)">
                            </div>

                            <div class="row">
                                <div class="col-md-6">
                                    <!-- Featured field -->
                                    <div class="form-group">
                                        <label for="featured">Featured</label>
                                        <select class="form-control" name="featured" id="featured" required>
                                            <option value="0" @if( $game->featured == 0) selected @endif>No</option>
                                            <option value="1" @if( $game->featured == 1) selected @endif>Yes</option>
                                        </select>
                                    </div>
                                </div>

                                <div class="col-md-6">
                                    <!-- Status field -->
                                    <div class="form-group">
                                        <label for="status">Status</label>
                                        <select class="form-control" name="status" id="status" required>
                                            <option value="1">Active</option>
                                            <option value="0">Inactive</option>
                                        </select>
                                    </div>
                                </div>
                            </div>

                        </div>
                        <!-- /.card-body -->

                        <div class="card-footer text-right">
                            <button type="submit" class="btn btn-primary">Submit</button>
                        </div>
                    </div>
                    <!-- /.card -->
                </div>

            </div>
        </form>

    </div><!--/. container-fluid -->
</section>

<!-- Move the scripts and styles directly into the content section -->
<style>
    .drop-area {
        border: 2px dashed #ccc;
        padding: 20px;
        text-align: center;
        cursor: pointer;
        transition: border-color 0.3s ease;
    }

    .drop-area.drag-over {
        border-color: #007bff;
    }

    .drop-area p {
        margin: 0;
        font-size: 16px;
    }
</style>

<script type="text/javascript">
    // Event listener for the "Translate" button
    document.querySelectorAll('.translateBtn').forEach(function(button) {
        button.addEventListener('click', function() {
            var key = this.getAttribute('data-key');
            var langCode = this.getAttribute('data-lang');
            var inputField = document.getElementById('name_' + langCode);
            var valueToTranslate = inputField.value.trim();

            // If textbox is empty, use the key itself for translation
            if (!valueToTranslate) {
                valueToTranslate = key; // Use the key as the translation if no value is entered
            }

            // Correct the language code for Chinese (Simplified)
            if (langCode === 'zn') {
                langCode = 'zh-CN'; // Change 'zn' to 'zh-CN' for Simplified Chinese
            }

            // Use Google Translate to get the translation for the input value
            var url = 'https://translate.googleapis.com/translate_a/single?client=gtx&sl=en&tl=' + langCode + '&dt=t&q=' + encodeURI(valueToTranslate);

            fetch(url)
                .then(response => response.json())
                .then(data => {
                    // Log the entire response to debug and inspect the structure
                    console.log('Translation Response:', data);

                    // Check if the data structure is valid
                    if (Array.isArray(data) && Array.isArray(data[0])) {
                        var translatedText = data[0][0][0]; // Extract the translated text correctly

                        // Check if the extracted translation is a string
                        if (typeof translatedText === 'string') {
                            // Clean up the response to get rid of any extra commas and metadata
                            var cleanTranslation = translatedText.split(',')[0]; // Only get the part before the first comma
                            inputField.value = cleanTranslation; // Set the clean translated text into the input field
                        } else {
                            console.error('The extracted translation is not a string:', translatedText);
                        }
                    } else {
                        console.error('Unexpected translation data structure:', data);
                    }
                })
                .catch(error => console.error('Error during translation:', error));
        });
    });

    // Event listener for translating description
    document.querySelectorAll('.DesctranslateBtn').forEach(function(button) {
        button.addEventListener('click', function() {
            var key = this.getAttribute('data-key');
            var langCode = this.getAttribute('data-lang');
            var inputField = document.getElementById('description_' + langCode);
            var valueToTranslate = inputField.value.trim();

            // If textbox is empty, use the key itself for translation
            if (!valueToTranslate) {
                valueToTranslate = key; // Use the key as the translation if no value is entered
            }

            // Correct the language code for Chinese (Simplified)
            if (langCode === 'zn') {
                langCode = 'zh-CN'; // Change 'zn' to 'zh-CN' for Simplified Chinese
            }

            // Split the text into individual sentences by punctuation (period, exclamation mark, question mark)
            var sentences = valueToTranslate.split(/(?<=[.!?])\s+/);

            // Make API calls for each sentence
            var promises = sentences.map(function(sentence) {
                var url = 'https://translate.googleapis.com/translate_a/single?client=gtx&sl=en&tl=' + langCode + '&dt=t&q=' + encodeURIComponent(sentence);

                return fetch(url)
                    .then(response => response.json())
                    .then(data => {
                        // Extract the translation for the sentence
                        if (Array.isArray(data) && Array.isArray(data[0])) {
                            return data[0][0][0]; // Return translated text
                        } else {
                            console.error('Unexpected translation data structure:', data);
                            return sentence; // Return original sentence if translation fails
                        }
                    })
                    .catch(error => {
                        console.error('Error during translation:', error);
                        return sentence; // Return original sentence if API call fails
                    });
            });

            // Wait for all sentence translations to finish and then join them together
            Promise.all(promises).then(translatedSentences => {
                // Combine all translated sentences back together
                inputField.value = translatedSentences.join(' ');
            });
        });
    });

</script>

<script>
    document.addEventListener('DOMContentLoaded', function () {
        function initDragAndDrop(dropAreaId, inputId, previewId) {
            let dropArea = document.getElementById(dropAreaId);
            let input = document.getElementById(inputId);
            let preview = document.getElementById(previewId);

            dropArea.addEventListener('dragover', (event) => {
                event.preventDefault();
                dropArea.classList.add('drag-over');
            });

            dropArea.addEventListener('dragleave', () => {
                dropArea.classList.remove('drag-over');
            });

            dropArea.addEventListener('drop', (event) => {
                event.preventDefault();
                dropArea.classList.remove('drag-over');
                input.files = event.dataTransfer.files;

                if (input.files.length > 0) {
                    const file = input.files[0];
                    const reader = new FileReader();

                    reader.onload = function(e) {
                        preview.src = e.target.result;
                        preview.style.display = 'block';
                    };

                    reader.readAsDataURL(file);
                }
            });

            dropArea.addEventListener('click', () => {
                input.click();
            });

            input.addEventListener('change', () => {
                if (input.files.length > 0) {
                    const file = input.files[0];
                    const reader = new FileReader();

                    reader.onload = function(e) {
                        preview.src = e.target.result;
                        preview.style.display = 'block';
                    };

                    reader.readAsDataURL(file);
                }
            });
        }

        initDragAndDrop('image-drop-area', 'image', 'image-preview');
        initDragAndDrop('banner-drop-area', 'banner', 'banner-preview');
    });
</script>
@endsection
