<!doctype html>
<html lang=en>

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, minimal-ui">

    <title>{{$game->name ?? ''}} - {{ old('website_name', $settings['website_name'] ?? '') }}</title>
    <meta name="description" content="{{$game->meta_description ?? ''}}">
    <meta name="keywords" content="{{$game->tags ?? ''}}">

    <link rel="icon" type="image/x-icon" href="{{asset('images/favicons/'.$settings['website_favicon'] ?? '')}}">

    <!-- Meta Image for Social Sharing -->
    <meta property="og:title" content="{{$game->name ?? ''}} - HTML Games">
    <meta property="og:description" content="{{$game->meta_description ?? ''}}">
    <meta property="og:image" content="{{asset('images/games/banner/' . $game->banner ?? '')}}">
    <meta property="og:url" content="{{ url('game/' . $game->slug ?? '') }}">

    {!! $settings['google_analytics'] ?? '' !!}

    <!-- Twitter Meta Tags -->
    <meta name="twitter:card" content="{{asset('images/games/banner/' . $game->banner ?? '')}}">
    <meta name="twitter:title" content="{{$game->name ?? ''}} - HTML Games">
    <meta name="twitter:description" content="{{$game->meta_description ?? ''}}">
    <meta name="twitter:image" content="{{asset('images/games/icons/' . $game->image ?? '')}}">

    <!-- Canonical URL (for SEO) -->
    <link rel="canonical" href="{{ url('game/' . $game->slug ?? '') }}">
    <link rel=stylesheet href="{{asset('frontend/gamegalore/css/play.css')}}" media=all>

    <style>
        /* Styles for the modal */
        .theme-modal {
            display: none; /* Hidden by default */
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5); /* Semi-transparent background */
            z-index: 1000;
        }

        /* Styles for the modal content */
        .modal-content {
            position: relative;
            background-color: #fff;
            margin: 10% auto;
            padding: 20px;
            width: 60%;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
        }

        /* Styles for the close button */
        .close-btn {
            position: absolute;
            top: 10px;
            right: 15px;
            font-size: 24px;
            font-weight: bold;
            color: #333;
            cursor: pointer;
        }

        /* Hover effect for the close button */
        .close-btn:hover {
            color: #000;
        }

        .theme-title {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 10px;
        }

        /* Initial style for the checkmark (hidden) */
        .checkmark {
            display: none;
            color: green;
            font-size: 18px;
        }

        /* Show the checkmark when theme is selected */
        .theme-card.selected .checkmark {
            display: inline;
        }
        /* Container for game iframe */
        #game-iframe-container {
            position: relative;
            display: inline-block;
            width: 100%;
            height: 100%;
        }

        /* Play button styling */
        .play-button {
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            background-color: rgba(0, 0, 0, 0.6);
            color: #fff;
            font-size: 3vw; /* Responsive size based on viewport width */
            width: 120px;
            height: 120px;
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            transition: background-color 0.3s;
        }

        /* Hover effect */
        .play-button:hover {
            background-color: rgba(0, 0, 0, 0.8);
        }

        /* Adjust size on smaller screens */
        @media (max-width: 600px) {
            .play-button {
                width: 50px;
                height: 50px;
                font-size: 4vw;
            }
        }
    </style>

    <script src={{asset('frontend/gamegalore/js/script.js')}}></script>
    <script>
        var lang='us';
    </script>
    <script src={{asset('frontend/gamegalore/js/cookie.js')}}></script>
    <script src={{asset('frontend/gamegalore/js/control.js')}}></script>
    <script src={{asset('frontend/gamegalore/js/common.js')}}></script>
    <script src={{asset('frontend/gamegalore/js/custom.js')}}></script>
    <link rel="stylesheet" href="{{asset('frontend/css/setting.css')}}">
    <script>
        window.projectId='2';window.siteUrl='https://gameforge.com/en-US/littlegames';window.apiEndpoint='https://little-games.com';window.marketingCookiesHint='A click on the play button or the game icon loads third-party content. You agree to load this content with your click. You can change this setting or revoke your consent at any time. More information: <a href=\"https://gameforge.com/en-US/littlegames/privacy-policy/\">Privacy Policy</a>.';var translation={search_games:'Search games',enter_search_term:'Enter search term',no_search_results:'No search results',search_term_must_be:'Search term must be at least 2 characters long',not_available_mobile:'Not fit for mobile'};
    </script>

</head>

<body class="page-template page-template-page-game page-template-page-game-php page page-id-11428 wp-embed-responsive bg-dark picostrap_header_navbar_position_ picostrap_header_navbar_color_choice_">

    @include('frontend.themes.gamegalore.partials._header')


    @if(env('DEMO_MODE') == 'on')

        <!-- Floating Settings Button -->
        <div id="settingsButton" onclick="openThemeModal()">⚙️ {{translate('Themes')}}</div>

        <!-- Theme Modal -->
        <div id="themeModal" class="theme-modal">
            @php
                $theme = App\Models\BusinessSettings::where('key', 'theme')->first()->value;
            @endphp
            <div class="modal-content">
                <span class="close-btn" onclick="closeThemeModal()">&times;</span>
                <h4>{{translate('Choose Theme')}}</h4>
                <hr>
                <section id="game-list">
                    <div class="theme-card" data-theme="playverse" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gameverse.jpg')}}" alt="PlayVerse">
                        <div class="theme-title">
                            <h6>PlayVerse</h6>
                            @if($theme == 'playverse')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                    <div class="theme-card" data-theme="gamehive" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gamehive.jpg')}}" alt="GameHive">
                        <div class="theme-title">
                            <h6>GameHive</h6>
                            @if($theme == 'gamehive')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                    <div class="theme-card" data-theme="gamegalore" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gamegalore.jpg')}}" alt="GameGalore">
                        <div class="theme-title">
                            <h6>GameGalore</h6>
                            @if($theme == 'gamegalore')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                </section>
            </div>
        </div>
    @endif

    <div class=content-section>
        <main id=main class="site-main pb-5" role=main>
            <section id="primary" class="container content-area justify-content-center container-fluid-lg-down">
                <div id="game-grid" class="row g-0 game-content game-grid" data-game-id="{{ $game->id }}" data-game-code="{{url($game->slug)}}">
                    <div id="gameplay">
                        <div class="gameplay-wrapper">
                            <a id="close-gamemode" class="shadow">
                                <svg version=1.1 id=Layer_1 xmlns=http://www.w3.org/2000/svg xmlns:xlink=http://www.w3.org/1999/xlink x=0px y=0px width=121.31px height=122.876px viewBox="0 0 121.31 122.876" enable-background="new 0 0 121.31 122.876" xml:space=preserve>
                                    <g>
                                        <path fill-rule=evenodd clip-rule=evenodd d="M90.914,5.296c6.927-7.034,18.188-7.065,25.154-0.068 c6.961,6.995,6.991,18.369,0.068,25.397L85.743,61.452l30.425,30.855c6.866,6.978,6.773,18.28-0.208,25.247 c-6.983,6.964-18.21,6.946-25.074-0.031L60.669,86.881L30.395,117.58c-6.927,7.034-18.188,7.065-25.154,0.068 c-6.961-6.995-6.992-18.369-0.068-25.397l30.393-30.827L5.142,30.568c-6.867-6.978-6.773-18.28,0.208-25.247 c6.983-6.963,18.21-6.946,25.074,0.031l30.217,30.643L90.914,5.296L90.914,5.296z"
                                        />
                                    </g>
                                </svg>
                            </a>
                            <div class="game-container">
                                <div class="game-loading">{{translate('Game is loading...')}}</div>

                                <div id="" class="iframe-container">
                                    <img id="game-iframe" name="game-iframe" src="{{asset('images/games/banner/'.$game->banner)}}" height="100%" width="100%" frameborder="0" allowtransparency="true" allow="autoplay; fullscreen" allowfullscreen="allowfullscreen"/>

                                    <!-- Play Button Overlay -->
                                    <a class="play-button" style="text-decoration: none" href="{{route('game.play', $game->slug)}}">
                                        &#9658;
                                    </a>
                                </div>
                            </div>


                        </div>
                    </div>
                    @foreach($relatedGames as $relGame)
                    <div class="game-col game-col-s2">
                        <div class="game-wrapper img-aspect-ratio-1x1 rounded-3 shadow image-popup game game--width15-off game--overview">
                            <a href="{{route('game', $relGame->slug)}}">
                                <img src="{{asset('images/games/icons/'.$relGame->image)}}"
                                alt="{{$relGame->name}}" title="{{$relGame->name}}" class="rounded-3 img-fluid" loading="lazy">
                                <div class=text>{{$relGame->name}}</div>
                            </a>
                        </div>
                    </div>
                    @endforeach

                    <article id="game-info" class="post-11428 page type-page status-publish hentry">
                        <div class="game-info">
                            <div class="game-info-wrapper">
                                <div class="entry-header">
                                    <h1 class="entry-title" style="margin-bottom: 0;">{{$game->name}}</h1>
                                    <div></div>
                                </div>
                                <div class="entry-content" style="margin-top: 0;">
                                    <div class="game-description">
                                        <div>
                                            <h2>Play {{$game->name}} free</h2>
                                            <p>{{ $game->description }}</p>
                                            <div id=below-game-aslot-336x280 class="aslot below-game-aslot-336x280">
                                                <div class="adsbyvli" data-ad-slot="vi_12067107470"></div>
                                            </div>
                                            <p>{{translate('Games Categories')}}:</p>
                                            <ul class="category-tags list-unstyled d-flex flex-wrap gutter">
                                                @foreach($categories as $category)
                                                    <li class="rounded-4 bg-secondary height-48 ts-hover-scale-10 shadow" data-url="{{route('category', $category->slug)}}">
                                                        <a href="{{route('category', $category->slug)}}" class="d-table-cell align-middle height-48">
                                                            <img src="{{ asset('images/categories/'.$category->image) }}" loading="lazy" class="height-48 rounded-4">
                                                            <span class="text small px-2 px-sm-3">{{$category->name}}</span>
                                                        </a>
                                                    </li>
                                                @endforeach
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </article>
                </div>
            </section>
        </main>
        @include('frontend.themes.gamegalore.partials._footer')
    </div>

    @include('frontend.themes.gamegalore.partials._footer-navbar')
    <script type="text/javascript" src="{{asset('frontend/js/bootstrap.bundle.min.js')}}"></script>
    <script defer src={{asset('frontend/gamegalore/js/footer.js')}}></script>

    <script>
        function openThemeModal() {
            document.getElementById('themeModal').style.display = 'flex';
        }

        function closeThemeModal() {
            document.getElementById('themeModal').style.display = 'none';
        }
    </script>


    <script>
        document.querySelectorAll('.theme-card').forEach(card => {
            card.addEventListener('click', function() {
                const selectedTheme = this.getAttribute('data-theme');

                fetch('{{route('set.theme')}}', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                        'X-CSRF-TOKEN': '{{ csrf_token() }}' // Include CSRF token
                    },
                    body: JSON.stringify({ theme: selectedTheme })
                })
                .then(response => {
                    if (!response.ok) {
                        throw new Error('Network response was not ok');
                    }
                    return response.json();
                })
                .then(data => {
                    if (data.success) {
                        location.reload();
                    } else {
                        alert('{{translate('Failed to change theme')}}');
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                });
            });
        });
    </script>

</body>

</html>
