@php
    $theme = App\Models\BusinessSettings::where('key', 'theme')->first()->value;
@endphp

@if($theme == 'playverse')


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{$game->name ?? ''}} - {{ old('website_name', $settings['website_name'] ?? '') }}</title>
    <meta name="description" content="{{$game->meta_description ?? ''}}">
    <meta name="keywords" content="{{$game->tags ?? ''}}">

    <link rel="icon" type="image/x-icon" href="{{asset('images/favicons/'.$settings['website_favicon'] ?? '')}}">

    <!-- Meta Image for Social Sharing -->
    <meta property="og:title" content="{{$game->name ?? ''}} - HTML Games">
    <meta property="og:description" content="{{$game->meta_description ?? ''}}">
    <meta property="og:image" content="{{asset('images/games/banner/' . $game->banner ?? '')}}">
    <meta property="og:url" content="{{ url('game/' . $game->slug ?? '') }}">

    {!! $settings['google_analytics'] ?? '' !!}

    <!-- Twitter Meta Tags -->
    <meta name="twitter:card" content="{{asset('images/games/banner/' . $game->banner ?? '')}}">
    <meta name="twitter:title" content="{{$game->name ?? ''}} - HTML Games">
    <meta name="twitter:description" content="{{$game->meta_description ?? ''}}">
    <meta name="twitter:image" content="{{asset('images/games/icons/' . $game->image ?? '')}}">

    <!-- Canonical URL (for SEO) -->
    <link rel="canonical" href="{{ url('game/' . $game->slug ?? '') }}">

    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="{{asset('frontend/css/style.css')}}">

    <link rel="stylesheet" href="{{asset('frontend/css/setting.css')}}">

    <link href="https://fonts.googleapis.com/css2?family=Orbitron:wght@400;700&display=swap" rel="stylesheet">

</head>

<body>

    <!-- Header -->
    @include('frontend.partials._header')

    <div class="container-fluid my-2">
        <div class="row">
            <div class="col-md-12 play-game-main mb-2">
                <div class="category-scroll-container" id="categoryScrollContainer">
                    <div class="d-flex flex-nowrap">
                        @foreach ($recentGames as $recent)
                            <div class="text-center me-4">
                                <a style="text-decoration: none;" class="text-white" href="{{route('game', $recent->slug)}}">
                                    <img src="{{asset('images/games/icons/' . $recent->image)}}" class="card-img-top mx-auto" style="width: 80px; height: 80px; object-fit: cover; border-radius: 5px;">
                                    <p>{{ Str::limit($recent->name, 15, '...')}}</p>
                                </a>
                            </div>
                        @endforeach
                    </div>
                </div>
            </div>

            <div class="col-lg-9">
                <div class="row">
                    <div class="col-lg-3 col-md-3 col-sm-12 mb-4 d-none d-lg-block">
                        <div class="row">
                            @foreach ($mostLikedGames as $liked)
                                <div class="col-md-4 text-center">
                                    <a class="text-white" style="text-decoration: none;" href="{{route('game', $liked->slug)}}">
                                        <img style="border-radius: 10px;" class="card-img-top mx-auto" src="{{asset('images/games/icons/' . $liked->image)}}" loading="lazy">
                                        <p class="text-truncate">{{Str::limit($liked->name, 15, '...')}}</p>
                                    </a>
                                </div>
                            @endforeach
                        </div>
                    </div>

                    <div class="col-lg-9 col-md-6 col-sm-12 mb-4 play-game-main">
                        @php
                            $categoryName = App\Models\Category::where('id', $game->category_id)->first();
                        @endphp
                        <h1 class="mb-4">{{$game->name}} <span class="text-red category-name" style="cursor: pointer;" onclick="location.href='{{route('category', $categoryName->slug)}}'"> {{$categoryName->name}}</span> </h1>

                        @if ($top_ads && $top_ads->type == 'custom')
                            @if ($top_ads->custom_html == null)
                                <div class="mt-3 mb-3">
                                    <img class="img-fluid mx-auto d-block" src="{{ asset('images/ads/' . $top_ads->custom_image) }}">
                                </div>
                            @else
                                <div class="mt-3 mb-3">
                                    {!! $top_ads->custom_html !!}
                                </div>
                            @endif

                        @else
                            {!! $top_ads->adsense_code !!}
                        @endif


                        <div class="ratio ratio-16x9 position-relative">
                            <img src="{{asset('images/games/banner/'.$game->banner)}}" class="img-fluid" alt="Game Thumbnail">
                            <a href="{{route('game.play', $game->slug)}}" class="play-button1">
                                <img src="{{asset('frontend/img/main_play.png')}}" alt="Play" class="play-img position-absolute top-50 start-50 translate-middle">
                            </a>
                        </div>
                        <div class="">
                            <p class="mt-2">{!! $game->description !!}</p>
                            <a href="{{route('game.play', $game->slug)}}" class="btn btn-primary">{{translate('Play Now')}}</a>
                        </div>
                        @if ($bottom_ads && $bottom_ads->type == 'custom')
                            @if ($bottom_ads->custom_html == null)
                                <div class="mt-3 mb-3">
                                    <img class="img-fluid mx-auto d-block" src="{{ asset('images/ads/' . $bottom_ads->custom_image) }}">
                                </div>
                            @else
                                <div class="mt-3 mb-3">
                                    {!! $bottom_ads->custom_html !!}
                                </div>
                            @endif

                        @else
                            {!! $bottom_ads->adsense_code !!}
                        @endif
                    </div>

                </div>
                <!-- Most Popular Games Section -->
            <div class="col-md-12 mt-2 mb-4">
                <h3 class="card-title mb-3">{{translate('Most Popular Games')}}</h3>
                <div class="row">
                    @foreach ($popularGames as $popular)
                        <div class="col-md-2 col-sm-4 col-6 mb-4">
                            <div class="popular-game-card text-center">
                                <a style="text-decoration: none;" href="{{route('game', $popular->slug)}}">
                                    <img src="{{ asset('images/games/icons/' . $popular->image) }}" class="popular-game-image" alt="{{ $popular->name }}" loading="lazy">
                                    <h6 class="mt-2 text-dark text-truncate">{{ $popular->name }}</h6>
                                </a>
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>
            </div>

            <div class="col-lg-3 col-md-3 col-sm-12 mb-4">
                <div class="bg-light p-4 mb-4">
                    <h5 class="card-title mb-2">{{translate('Advertisement')}}</h5>

                    @foreach ($sidebar_ads as $sidebarad)
                        @if($sidebarad->type == 'custom')

                            @if ($sidebarad->custom_html == null)
                                <a href="{{$sidebarad->custom_link}}" target="_blank">
                                    <img src="{{asset('images/ads/'.$sidebarad->custom_image)}}" class="img-fluid w-100" alt="Ad Placeholder" loading="lazy">
                                </a>
                            @else
                                <div class="mt-3 mb-3">
                                    {!! $sidebarad->custom_html !!}
                                </div>
                            @endif

                        @else
                            {!! $sidebarad->adsense_code !!}
                        @endif
                    @endforeach


                </div>
                <div class="bg-light p-4">
                    <h5 class="card-title mb-3">{{translate('Related Games')}}</h5>
                    <div class="row related-games">
                        <div class="col-md-12">
                            <div class="row">
                                @foreach ($relatedGames as $related)
                                    <div class="col-md-4 col-sm-6 col-6 mb-4">
                                        <div class="related-game-card text-center">
                                            <a href="{{ route('game', $related->slug) }}" class="text-decoration-none">
                                                <div class="fixed-size-image-container">
                                                    <img src="{{ asset('images/games/icons/' . $related->image) }}" class="card-img-top fixed-size-image" alt="{{ $related->name }}" loading="lazy">
                                                    <a href="{{ route('game', $related->slug) }}" class="play-button position-absolute top-50 start-50 translate-middle">
                                                        <img src="{{ asset('frontend/img/play.png') }}" alt="Play" class="play-icon">
                                                    </a>
                                                </div>
                                                <div class="card-body text-center">
                                                    <h6 class="mt-2 text-dark text-truncate">{{ $related->name }}</h6>
                                                </div>
                                            </a>
                                        </div>
                                    </div>
                                @endforeach
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    @if(env('DEMO_MODE') == 'on')

        <!-- Floating Settings Button -->
        <div id="settingsButton" onclick="openThemeModal()">⚙️ {{translate('Themes')}}</div>

        <!-- Theme Modal -->
        <div id="themeModal" class="theme-modal">
            @php
                $theme = App\Models\BusinessSettings::where('key', 'theme')->first()->value;
            @endphp
            <div class="modal-content">
                <span class="close-btn" onclick="closeThemeModal()">&times;</span>
                <h4>{{translate('Choose Theme')}}</h4>
                <hr>
                <section id="game-list">
                    <div class="theme-card" data-theme="playverse" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gameverse.jpg')}}" alt="PlayVerse">
                        <div class="theme-title">
                            <h6>PlayVerse</h6>
                            @if($theme == 'playverse')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                    <div class="theme-card" data-theme="gamehive" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gamehive.jpg')}}" alt="GameHive">
                        <div class="theme-title">
                            <h6>GameHive</h6>
                            @if($theme == 'gamehive')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                    <div class="theme-card" data-theme="gamegalore" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gamegalore.jpg')}}" alt="GameGalore">
                        <div class="theme-title">
                            <h6>GameGalore</h6>
                            @if($theme == 'gamegalore')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                </section>
            </div>
        </div>

    @endif

    <!-- Footer -->
    @include('frontend.partials._footer')

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            const scrollContainer = document.getElementById('categoryScrollContainer');

            let scrollAmount = 0;
            let autoScrollInterval;

            function autoScroll() {
                scrollAmount += 1;
                scrollContainer.scrollLeft = scrollAmount;

                if (scrollAmount >= scrollContainer.scrollWidth - scrollContainer.clientWidth) {
                    scrollAmount = 0;
                }
            }

            function startAutoScroll() {
                autoScrollInterval = setInterval(autoScroll, 50);
            }

            function stopAutoScroll() {
                clearInterval(autoScrollInterval);
            }

            startAutoScroll();

            scrollContainer.addEventListener('mouseenter', stopAutoScroll);
            scrollContainer.addEventListener('mouseleave', startAutoScroll);
        });
    </script>
</body>

</html>

@elseif($theme == 'gamehive')
    @include('frontend.details.gamehive')

@elseif($theme == 'gamegalore')

@include('frontend.details.gamegalore')

@endif

<script>
    function openThemeModal() {
        document.getElementById('themeModal').style.display = 'flex';
    }

    function closeThemeModal() {
        document.getElementById('themeModal').style.display = 'none';
    }
</script>


<script>
    document.querySelectorAll('.theme-card').forEach(card => {
        card.addEventListener('click', function() {
            const selectedTheme = this.getAttribute('data-theme');

            fetch('{{route('set.theme')}}', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'X-CSRF-TOKEN': '{{ csrf_token() }}' // Include CSRF token
                },
                body: JSON.stringify({ theme: selectedTheme })
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.json();
            })
            .then(data => {
                if (data.success) {
                    location.reload();
                } else {
                    alert('Failed to change theme');
                }
            })
            .catch(error => {
                console.error('Error:', error);
            });
        });
    });
</script>
