@php
    // Fetch the main menu value from BusinessSettings
    $mainMenu = App\Models\BusinessSettings::where('key', 'main_menu')->first();
    if ($mainMenu && $mainMenu->value) {
        // Fetch the menu using the value from the main menu settings
        $selectedMenu = App\Models\Menus::where('id', $mainMenu->value)->first();
    }
    $menuItems = App\Models\MenuItems::where('menu_id', $selectedMenu->id)->orderBy('order', 'asc')->get();

    $loginEnabled = App\Models\BusinessSettings::where('key', 'header_login')->first()->value;
    $searchEnabled = App\Models\BusinessSettings::where('key', 'header_search')->first()->value;
    $logo = App\Models\BusinessSettings::where('key', 'website_logo')->first()->value;
    $websiteName = App\Models\BusinessSettings::where('key', 'website_name')->first()->value;
    $languages = \App\Models\Languages::where('status', 1)->get();
@endphp


<header class="header">
    <div class="header-content">
        <div class="main-head">
            <!-- Logo -->
            <div class="logo">
                @if($logo == null)
                    <a href="{{ route('home') }}" style="text-decoration: none; color:#ffffff;">
                        <h1 style="font-weight: 600; font-size: 30px;">{{$websiteName}}</h1>
                    </a>
                @else
                    <a href="{{ route('home') }}" style="text-decoration: none; color:#ffffff;">
                        <img src="{{ asset('images/logos/'.$logo) }}" width="100">
                    </a>
                @endif
            </div>

            <!-- Drawer Toggle Button (Visible in Mobile View) -->
            <button id="drawer-toggle" class="drawer-toggle">☰</button>

            <!-- Navigation Menu (Hidden in Mobile View) -->
            <nav class="nav-menu">
                <ul id="categories" class="swipe-menu">
                    @foreach ($menuItems as $item)
                        <li class="{{ Request::is(trim($item->url, '/')) ? 'active' : '' }}">
                            <a class="nav-link" href="{{ $item->url }}">
                                {{ translate($item->title) }}
                            </a>
                        </li>
                    @endforeach

                </ul>
            </nav>

            <div class="d-flex">
                @if ($loginEnabled == 1)
                    @auth
                        <div class="dropdown ms-1 m-1 mt-2 d-none d-md-block">
                            <button class="btn btn-secondary dropdown-toggle" type="button" id="userMenuDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                                <img src="{{ Auth::user()->image ? asset('images/user/' . Auth::user()->image) : asset('images/default-avatar.avif') }}" width="30" height="30" class="rounded-circle ms-2">
                            </button>


                            <ul class="dropdown-menu" aria-labelledby="userMenuDropdown">
                                <li><a class="dropdown-item" href="{{route('user.profile')}}"><i class="bi bi-user"></i>{{translate('Profile')}}</a></li>
                                <li><a class="dropdown-item" href="{{route('user.liked')}}">{{translate('Liked Games')}}</a></li>
                                <li><a class="dropdown-item" href="{{route('user.history')}}">{{translate('History')}}</a></li>
                                <li><hr class="dropdown-divider"></li>
                                <li>
                                    <a class="dropdown-item" href="{{ route('logout') }}"
                                        onclick="event.preventDefault(); document.getElementById('logout-form').submit();">
                                        {{translate('Logout')}}
                                    </a>
                                    <form id="logout-form" action="{{ route('logout') }}" method="POST" class="d-none">
                                        @csrf
                                    </form>
                                </li>
                            </ul>
                        </div>
                    @endauth

                    @guest
                        <!-- Login and Register Buttons (Hidden in Mobile View) -->
                        <div class="accounts">
                            <a href="{{ route('user.login') }}" style="text-decoration: none; background:transparent;" class="btn btn-secondary login-btn">{{translate('Login')}}</a>
                        </div>
                    @endguest
                @endif

                <div class="dropdown ms-1 m-1 mt-2 text-center d-none d-md-block">
                    <button style="background:transparent;" class="btn btn-secondary dropdown-toggle" type="button" id="userMenuDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                        <img src="{{ asset('frontend/flags/' . currentLanguage()['flag']) }}" width="30" height="30" class="rounded-circle ms-2">
                        {{ currentLanguage()['name'] }}
                    </button>
                    <ul class="dropdown-menu" aria-labelledby="userMenuDropdown">
                        @foreach($languages as $lang)
                            <li>
                                <a class="dropdown-item" href="{{ route('change.language', $lang->code) }}">
                                    <img src="{{ asset('frontend/flags/' . $lang->app_lang_code . '.svg') }}" width="20" height="20" class="me-2">
                                    {{ $lang->name }}
                                </a>
                            </li>
                        @endforeach
                    </ul>
                </div>
            </div>
        </div>
    </div>
</header>

<!-- Drawer for Mobile View -->
<div id="drawer" class="drawer">
    <button id="close-drawer" class="close-drawer">✖</button>
    <ul class="drawer-menu">
        @foreach ($menuItems as $item)
            <li class="{{ Request::is(trim($item->url, '/')) ? 'active' : '' }}">
                <a class="nav-link" href="{{ $item->url }}">
                    {{ $item->title }}
                </a>
            </li>
        @endforeach
    </ul>
</div>
