@php
    $theme = App\Models\BusinessSettings::where('key', 'theme')->value('value');
@endphp

@if($theme == 'playverse')
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{$game->name}} - {{ old('website_name', $settings['website_name'] ?? '') }}</title>
    <link rel="icon" type="image/x-icon" href="{{asset('images/favicons/'.$settings['website_favicon'] ?? '')}}">

    <meta name="description" content="{{$game->meta_description}}">
    <meta name="keywords" content="{{$game->tags}}">

    <!-- Meta Image for Social Sharing -->
    <meta property="og:title" content="{{$game->name}} - HTML Games">
    <meta property="og:description" content="{{$game->meta_description}}">
    <meta property="og:image" content="{{asset('images/games/banner/' . $game->banner)}}">
    <meta property="og:url" content="{{ url('game/' . $game->slug) }}">

    {!! $settings['google_analytics'] !!}

    <!-- Twitter Meta Tags -->
    <meta name="twitter:card" content="{{asset('images/games/banner/' . $game->banner)}}">
    <meta name="twitter:title" content="{{$game->name}} - HTML Games">
    <meta name="twitter:description" content="{{$game->meta_description}}">
    <meta name="twitter:image" content="{{asset('images/games/icons/' . $game->image)}}">

    <!-- Canonical URL (for SEO) -->
    <link rel="canonical" href="{{ url('game/' . $game->slug) }}">

    <link href="{{asset('frontend/css/bootstrap.min.css')}}" rel="stylesheet">
    <link rel="stylesheet" href="{{asset('frontend/css/style.css')}}">
    <link rel="stylesheet" href="{{asset('frontend/css/setting.css')}}">
    <style>
        .category-name{font-size:16px;color:#d47217;top:0}.bg-light,.btn-primary,body{color:#f0f0f0}iframe{position:fixed;top:0;left:0;width:100vw;height:100vh;border:none;z-index:999}.category-scroll-container{overflow-x:auto;white-space:nowrap;scrollbar-width:none}.category-scroll-container::-webkit-scrollbar{display:none}body{background-color:#121212}.btn-primary{background-color:#fc0;border:none;font-weight:700;text-transform:uppercase;letter-spacing:1px}.btn-primary:hover{background-color:#e6b800}.ratio-16x9 iframe{border:2px solid #fc0;border-radius:5px}.bg-light{background-color:#1e1e1e!important}

    </style>
    <link href="https://fonts.googleapis.com/css2?family=Orbitron:wght@400;700&display=swap" rel="stylesheet">
</head>

<body>

    <!-- Header -->
    @include('frontend.partials._header')

    <!-- Game Area -->
    <div class="container-fluid my-2">
        <div class="row">
            <div class="col-md-12 play-game-main mb-2">
                <div class="category-scroll-container" id="categoryScrollContainer">
                    <div class="d-flex flex-nowrap">
                        <!-- Category 1 -->
                        @foreach ($recentGames as $recent)
                            <div class="text-center me-4">
                                <a style="text-decoration: none;color:#f0f0f0;" href="{{route('game.play', $recent->slug)}}">
                                    <img src="{{asset('images/games/icons/' . $recent->image)}}" class="card-img-top mx-auto" style="border-radius: 5px; width: 80px; height: 80px; object-fit: cover;">
                                    <p>{{ Str::limit($recent->name, 15, '...')}}</p>
                                </a>
                            </div>
                        @endforeach
                    </div>
                </div>
            </div>

            <div class="col-md-12">
                <div class="row">
                    <div class="col-lg-2 col-md-3 col-sm-12 mb-4 d-none d-lg-block play-game-main">
                        <div class="row">
                            @foreach ($relatedGames as $related)
                                <div class="col-md-4 text-center">
                                    <a class="text-white" style="text-decoration: none;" href="{{route('game.play', $related->slug)}}">
                                        <img style="border-radius: 10px;" class="card-img-top mx-auto" src="{{asset('images/games/icons/' . $related->image)}}" loading="lazy">
                                        <p class="text-truncate">{{$related->name}}</p>
                                    </a>
                                </div>
                            @endforeach
                        </div>
                    </div>

                    <div class="col-md-7">
                        <div class="ratio ratio-16x9">
                            <!-- The iframe that plays the game -->
                            <iframe id="game_iframe" src="{{$game->game_url}}" frameborder="0" allowfullscreen></iframe>
                        </div>
                        <div class="play-game-main">
                            <div class="d-flex justify-content-between align-items-center mt-3">
                                <div>
                                    <h3>{{ Str::limit($game->name, 20) }}</h3>
                                </div>
                                <div>
                                    <button id="like-button" class="btn btn-sm btn-success me-2">
                                        <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="icon icon-tabler icons-tabler-outline icon-tabler-thumb-up">
                                            <path stroke="none" d="M0 0h24v24H0z" fill="none"/>
                                            <path d="M7 11v8a1 1 0 0 1 -1 1h-2a1 1 0 0 1 -1 -1v-7a1 1 0 0 1 1 -1h3a4 4 0 0 0 4 -4v-1a2 2 0 0 1 4 0v5h3a2 2 0 0 1 2 2l-1 5a2 3 0 0 1 -2 2h-7a3 3 0 0 1 -3 -3" />
                                        </svg>
                                        <span id="like-count">{{ \App\Helpers\NumberFormatter::formatNumber($game->reactions->where('like', true)->count()) }}</span>
                                    </button>

                                    <button id="dislike-button" class="btn btn-sm btn-danger me-2">
                                        <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="icon icon-tabler icons-tabler-outline icon-tabler-thumb-down">
                                            <path stroke="none" d="M0 0h24v24H0z" fill="none"/>
                                            <path d="M7 13v-8a1 1 0 0 0 -1 -1h-2a1 1 0 0 0 -1 1v7a1 1 0 0 0 1 1h3a4 4 0 0 1 4 4v1a2 2 0 0 0 4 0v-5h3a2 2 0 0 0 2 -2l-1 -5a2 3 0 0 0 -2 -2h-7a3 3 0 0 0 -3 3" />
                                        </svg>
                                        <span id="dislike-count">{{ \App\Helpers\NumberFormatter::formatNumber($game->reactions->where('dislike', true)->count()) }}</span>
                                    </button>

                                    <button class="btn btn-sm btn-secondary" onclick="toggleFullscreen()">
                                        <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="icon icon-tabler icons-tabler-outline icon-tabler-maximize">
                                            <path stroke="none" d="M0 0h24v24H0z" fill="none"/>
                                            <path d="M4 8v-2a2 2 0 0 1 2 -2h2" />
                                            <path d="M4 16v2a2 2 0 0 0 2 2h2" />
                                            <path d="M16 4h2a2 2 0 0 1 2 2v2" />
                                            <path d="M16 20h2a2 2 0 0 0 2 -2v-2" />
                                        </svg>
                                    </button>
                                </div>
                            </div>
                            <p class="mt-4">{!! $game->description !!}</p>
                        </div>


                        <!-- Comments Section -->
                        <div class="container-fluid my-5 mt-2 play-game-main">
                            <h4>{{translate('User Comments')}}</h4>
                            <div class="mb-3 col-md-12">
                                @auth
                                    <form id="comment-form">
                                        @csrf
                                        <label for="comment" class="form-label">{{translate('Leave a Comment')}}</label>
                                        <textarea class="form-control" id="comment" name="comment" placeholder="{{translate('Type your comment...')}}" rows="3" required></textarea>
                                        <button type="submit" class="btn btn-primary mt-3">{{translate('Submit')}}</button>
                                    </form>
                                @else
                                    <p>{{translate('Please')}} <a href="{{ route('login') }}">{{translate('log in')}}</a> {{translate('to leave a comment')}}.</p>
                                @endauth
                            </div>

                            <!-- Display user comments here -->
                            <div id="comments" class="comments mt-4">
                                @foreach($game->comments as $comment)
                                    <div class="comment mb-4 p-3" style="border: 1px solid #e0e0e0; border-radius: 8px; background-color: #5a5757;">
                                        <div class="d-flex align-items-center mb-2">
                                            <img src="{{ $comment->user->profile_photo_url ?? 'https://via.placeholder.com/40' }}" class="rounded-circle me-3" alt="User Avatar">
                                            <strong>{{ $comment->user->name }}</strong>
                                        </div>
                                        <p class="mb-2">{{ $comment->comment }}</p>
                                        <small class="text-white">{{ $comment->created_at->diffForHumans() }}</small>

                                        <!-- Reply form (hidden by default) -->
                                        <div class="reply-section mt-3">
                                            <a href="#" class="reply-btn text-primary">{{translate('Reply')}}</a>
                                            <form class="reply-form mt-2" style="display:none;" action="{{ route('games.reply', ['comment' => $comment->id]) }}" method="POST">
                                                @csrf
                                                <textarea class="form-control" name="reply" rows="2" placeholder="{{translate('Write a reply')}}"></textarea>
                                                <button type="submit" class="btn btn-primary mt-2">{{translate('Submit Reply')}}</button>
                                            </form>
                                        </div>

                                        <!-- Display replies here -->
                                        <div class="replies mt-3">
                                            @foreach($comment->replies as $reply)
                                                <div class="reply mb-2">
                                                    <strong>{{ $reply->user->name }}</strong>
                                                    <p>{{ $reply->comment }}</p>
                                                    <small>{{ $reply->created_at->diffForHumans() }}</small>
                                                </div>
                                            @endforeach
                                        </div>
                                    </div>
                                @endforeach
                            </div>
                        </div>


                    </div>
                    <div class="col-md-3">
                        <!-- Ad Space -->
                        <div class="bg-light p-4 mb-4">
                            <h5>{{translate('Advertisement')}}</h5>
                            @foreach ($sidebar_ads as $sidebarad)
                                @if($sidebarad->type == 'custom')

                                    @if ($sidebarad->custom_html == null)
                                        <a href="{{$sidebarad->custom_link}}" target="_blank">
                                            <img src="{{asset('images/ads/'.$sidebarad->custom_image)}}" class="img-fluid w-100" alt="Ad Placeholder" loading="lazy">
                                        </a>
                                    @else
                                        <div class="mt-3 mb-3">
                                            {!! $sidebarad->custom_html !!}
                                        </div>
                                    @endif

                                @else
                                    {!! $sidebarad->adsense_code !!}
                                @endif
                            @endforeach
                        </div>
                        <!-- Game Info Panel -->
                        <div class="bg-light p-4">
                            <h5>{{translate('Game Information')}}</h5>
                            <ul>
                                <li>Mouse/Touchpad: Most HTML5 games use the mouse or touchpad for primary interactions. For example:</li>
                                    <ul>
                                        <li>Click: Click to select options, start the game, or perform actions like shooting or jumping.</li>
                                        <li>Drag and Drop: For games involving dragging elements, hold the left mouse button and move the mouse to drag objects.</li>
                                    </ul>
                                <li>Keyboard: Some games might require keyboard input. Common controls include:</li>
                                    <ul>
                                        <li>Arrow Keys (↑, ↓, ←, →): Move your character, navigate menus, or control in-game movement.</li>
                                        <li>Spacebar: Often used for actions like jumping, shooting, or pausing the game.</li>
                                        <li>Enter/Return: Start the game or confirm selections.</li>
                                        <li>Esc: Pause the game or access the game menu.</li>
                                    </ul>
                                <li>Game Objectives:</li>
                                    <ul>
                                        <li>Read the game’s objective, usually provided on the start screen or within a tutorial.</li>
                                        <li>Follow any in-game prompts or tutorials that guide you through the first few levels or actions.</li>
                                    </ul>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    @if(env('DEMO_MODE') == 'on')

        <!-- Floating Settings Button -->
        <div id="settingsButton" onclick="openThemeModal()">⚙️ {{translate('Themes')}}</div>

        <!-- Theme Modal -->
        <div id="themeModal" class="theme-modal">
            @php
                $theme = App\Models\BusinessSettings::where('key', 'theme')->first()->value;
            @endphp
            <div class="modal-content">
                <span class="close-btn" onclick="closeThemeModal()">&times;</span>
                <h4>{{translate('Choose Theme')}}</h4>
                <hr>
                <section id="game-list">
                    <div class="theme-card" data-theme="playverse" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gameverse.jpg')}}" alt="PlayVerse">
                        <div class="theme-title">
                            <h6>PlayVerse</h6>
                            @if($theme == 'playverse')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                    <div class="theme-card" data-theme="gamehive" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gamehive.jpg')}}" alt="GameHive">
                        <div class="theme-title">
                            <h6>GameHive</h6>
                            @if($theme == 'gamehive')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                    <div class="theme-card" data-theme="gamegalore" onclick="selectTheme(this)">
                        <img src="{{asset('themes/gamegalore.jpg')}}" alt="GameGalore">
                        <div class="theme-title">
                            <h6>GameGalore</h6>
                            @if($theme == 'gamegalore')
                                <svg height="30px" width="30px" version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 512 512" xml:space="preserve" fill="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"> <polygon style="fill:#8add88;" points="226.4,283.284 134.616,192.636 74.096,259.316 233.48,416.708 512,73.084 444.792,13.812 "></polygon> <polygon style="fill:#578109;" points="274.04,149.996 274.04,109.996 0,109.996 0,498.188 345.88,498.188 345.88,409.204 305.88,409.204 305.88,458.188 40,458.188 40,149.996 "></polygon> </g></svg>
                            @endif
                        </div>
                    </div>
                </section>
            </div>
        </div>

    @endif

    <!-- Footer -->
    @include('frontend.partials._footer')

    <script src="{{asset('frontend/js/bootstrap.bundle.min.js')}}"></script>

    <script>
        function toggleFullscreen() {
            const iframe = document.querySelector('iframe');
            if (iframe.requestFullscreen) {
                iframe.requestFullscreen();
            } else if (iframe.mozRequestFullScreen) { // Firefox
                iframe.mozRequestFullScreen();
            } else if (iframe.webkitRequestFullscreen) { // Chrome, Safari and Opera
                iframe.webkitRequestFullscreen();
            } else if (iframe.msRequestFullscreen) { // IE/Edge
                iframe.msRequestFullscreen();
            }
        }
    </script>

<script>
    document.addEventListener("DOMContentLoaded", function() {
        const iframe = document.getElementById('game_iframe');

        // Function to request fullscreen
        function openFullscreen() {
            if (iframe.requestFullscreen) {
                iframe.requestFullscreen();
            } else if (iframe.mozRequestFullScreen) { // Firefox
                iframe.mozRequestFullScreen();
            } else if (iframe.webkitRequestFullscreen) { // Chrome, Safari, and Opera
                iframe.webkitRequestFullscreen();
            } else if (iframe.msRequestFullscreen) { // IE/Edge
                iframe.msRequestFullscreen();
            }
        }

        // Open fullscreen on page load
        openFullscreen();
    });
</script>

<script>
    function openThemeModal() {
        document.getElementById('themeModal').style.display = 'flex';
    }

    function closeThemeModal() {
        document.getElementById('themeModal').style.display = 'none';
    }
</script>
<script>
    document.querySelectorAll('.theme-card').forEach(card => {
        card.addEventListener('click', function() {
            const selectedTheme = this.getAttribute('data-theme');

            fetch('{{route('set.theme')}}', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                    'X-CSRF-TOKEN': '{{ csrf_token() }}' // Include CSRF token
                },
                body: JSON.stringify({ theme: selectedTheme })
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.json();
            })
            .then(data => {
                if (data.success) {
                    location.reload();
                } else {
                    alert('Failed to change theme');
                }
            })
            .catch(error => {
                console.error('Error:', error);
            });
        });
    });


</script>
<script>
    document.addEventListener('DOMContentLoaded', function () {
        const scrollContainer = document.getElementById('categoryScrollContainer');

        let scrollAmount = 0;
        function autoScroll() {
            scrollAmount += 1; // Adjust this value for speed
            scrollContainer.scrollLeft = scrollAmount;

            if (scrollAmount >= scrollContainer.scrollWidth - scrollContainer.clientWidth) {
                scrollAmount = 0; // Reset to start if reached the end
            }
        }

        setInterval(autoScroll, 50); // Adjust the interval for speed
    });
</script>

</body>

</html>


@elseif ($theme == 'gamehive')
    @include('frontend.play.gamehive')

@elseif ($theme == 'gamegalore')
    @include('frontend.play.gamegalore')
@endif

<script src="{{asset('frontend/js/jquery.min.js')}}"></script>
<script>
    $(document).ready(function() {
        $('#like-button').click(function() {
            $.ajax({
                url: '{{ route("games.like", $game->id) }}',
                type: 'POST',
                data: {
                    _token: '{{ csrf_token() }}',
                },
                success: function(response) {
                    $('#like-count').text(response.likes);
                    $('#dislike-count').text(response.dislikes);

                    if ($('#like-button').hasClass('active')) {
                        $('#like-button').removeClass('active');
                    } else {
                        $('#like-button').addClass('active');
                        $('#dislike-button').removeClass('active');
                    }
                },
                error: function(response) {
                    alert('{{translate('You need to login first')}}');
                }
            });
        });

        $('#dislike-button').click(function() {
            $.ajax({
                url: '{{ route("games.dislike", $game->id) }}',
                type: 'POST',
                data: {
                    _token: '{{ csrf_token() }}',
                },
                success: function(response) {
                    $('#like-count').text(response.likes);
                    $('#dislike-count').text(response.dislikes);

                    if ($('#dislike-button').hasClass('active')) {
                        $('#dislike-button').removeClass('active');
                    } else {
                        $('#dislike-button').addClass('active');
                        $('#like-button').removeClass('active');
                    }
                },
                error: function(response) {
                    alert('{{translate('You need to login first')}}');
                }
            });
        });
    });
</script>

@if($theme == 'playverse' || $theme == 'gamegalore')

<script>

$(document).ready(function() {
    // Handle comment submission
    $('#comment-form').submit(function(e) {
        e.preventDefault(); // Prevent the page from reloading
        var formData = $(this).serialize(); // Get the form data

        $.ajax({
            url: "{{ route('games.comment', $game->id) }}", // Laravel route
            method: "POST",
            data: formData,
            success: function(response) {
                // Append new comment to the comments section
                $('#comments').prepend(`
                    <div class="comment mb-4 p-3" style="border: 1px solid #e0e0e0; border-radius: 8px; background-color: #5a5757;">
                        <div class="d-flex align-items-center mb-2">
                            <img width="40" src="${response.user_profile_photo}" class="rounded-circle me-3" alt="User Avatar">
                            <strong>${response.user_name}</strong>
                        </div>
                        <p class="mb-2">${response.comment}</p>
                        <small class="text-white">${response.created_at}</small>
                    </div>
                `);
                $('#comment').val(''); // Clear the comment box
            },
            error: function(xhr) {
                alert('Something went wrong!');
            }
        });
    });

    // Show reply form
    $(document).on('click', '.reply-btn', function(e) {
        e.preventDefault();
        $(this).siblings('.reply-form').toggle(); // Toggle reply form visibility
    });

    // Handle reply submission
    $(document).on('submit', '.reply-form', function(e) {
        e.preventDefault(); // Prevent the page from reloading
        var formData = $(this).serialize(); // Get the form data
        var commentDiv = $(this).closest('.comment'); // The parent comment div
        var actionUrl = $(this).attr('action'); // Get the action URL from the form

        $.ajax({
            url: actionUrl, // Use the action attribute of the form
            method: "POST",
            data: formData,
            success: function(response) {
                // Append new reply to the replies section
                commentDiv.find('.replies').append(`
                    <div class="reply mb-2">
                        <strong>${response.user_name}</strong>
                        <p>${response.reply}</p>
                        <small>${response.created_at}</small>
                    </div>
                `);
                $(this).hide(); // Hide the reply form
            },
            error: function(xhr) {
                alert('Something went wrong!');
            }
        });
    });
});
</script>
@elseif($theme == 'gamehive')

<script>
    $(document).ready(function() {
        // Handle comment submission
        $('#comment-form').submit(function(e) {
            e.preventDefault(); // Prevent the page from reloading
            var formData = $(this).serialize(); // Get the form data

            $.ajax({
                url: "{{ route('games.comment', $game->id) }}", // Laravel route
                method: "POST",
                data: formData,
                success: function(response) {
                    // Append new comment to the comments section
                    $('#comments').prepend(`
                        <div class="comment mb-4 p-3" style="border: 1px solid #e0e0e0; border-radius: 8px; background-color: #5a575700;">
                            <div class="d-flex align-items-center mb-2">
                                <img width="40" src="${response.user_profile_photo}" class="rounded-circle me-3" alt="User Avatar">
                                <strong>${response.user_name}</strong>
                            </div>
                            <p class="mb-2">${response.comment}</p>
                            <small class="text-dark">${response.created_at}</small>
                        </div>
                    `);
                    $('#comment').val(''); // Clear the comment box
                },
                error: function(xhr) {
                    alert('{{translate('Something went wrong!')}}');
                }
            });
        });

        // Show reply form
        $(document).on('click', '.reply-btn', function(e) {
            e.preventDefault();
            $(this).siblings('.reply-form').toggle(); // Toggle reply form visibility
        });

        // Handle reply submission
        $(document).on('submit', '.reply-form', function(e) {
            e.preventDefault(); // Prevent the page from reloading
            var formData = $(this).serialize(); // Get the form data
            var commentDiv = $(this).closest('.comment'); // The parent comment div
            var actionUrl = $(this).attr('action'); // Get the action URL from the form

            $.ajax({
                url: actionUrl, // Use the action attribute of the form
                method: "POST",
                data: formData,
                success: function(response) {
                    // Append new reply to the replies section
                    commentDiv.find('.replies').append(`
                        <div class="reply mb-2">
                            <strong>${response.user_name}</strong>
                            <p>${response.reply}</p>
                            <small>${response.created_at}</small>
                        </div>
                    `);
                    $(this).hide(); // Hide the reply form
                },
                error: function(xhr) {
                    alert('Something went wrong!');
                }
            });
        });
    });
</script>
@endif
