<?php

use App\Http\Controllers\AdminController;
use App\Http\Controllers\AdvertisementController;
use App\Http\Controllers\APIController;
use App\Http\Controllers\BlogCategoryController;
use App\Http\Controllers\BlogPostController;
use App\Http\Controllers\BusinessSettingsController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\DynamicPopupsController;
use App\Http\Controllers\GameController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\LanguagesController;
use App\Http\Controllers\MenuItemsController;
use App\Http\Controllers\MenusController;
use App\Http\Controllers\PagesController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\SitemapController;
use App\Http\Controllers\SocialLoginController;
use App\Http\Controllers\SubscriberController;
use App\Http\Controllers\ThemesController;
use App\Http\Controllers\TranslationController;
use App\Http\Controllers\UserController;
use App\Models\Advertisement;
use App\Models\BlogPost;
use App\Models\CountryVisit;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Cookie;

// Route::get('/', function () {
//     return view('welcome');
// });


Route::controller(HomeController::class)->middleware('trackPage')->group(function () {
    Route::get('/', 'index')->name('home');
    Route::get('/about', 'about')->name('about');
    Route::get('/contact', 'contact')->name('contact');
    Route::get('/top-games', 'topGames')->name('top.games');
});

Route::get('/admin/country-visits', function () {
    $visits = CountryVisit::all();
    return response()->json($visits);
});

Route::post('/save-location', [DashboardController::class, 'saveLocation']);

Route::get('change-language/{code}', function ($code) {
    // Store the selected locale in the session
    session()->put('locale', $code);

    // Store the locale in the cookie for persistence
    Cookie::queue('app_locale', $code, 525600);  // Store for 1 year

    // Set the application's locale
    App::setLocale($code);

    // Redirect back to the previous page
    return redirect()->back();
})->name('change.language');

 // Clear cache
Route::get('/clear-cache', function() {
    Artisan::call('cache:clear');
    Artisan::call('config:clear');
    Artisan::call('route:clear');
    Artisan::call('view:clear');

    return back()->with('success', 'Cache Cleared Successfully!');
})->name('clear.cache');

Route::get('/sitemap.xml', [SitemapController::class, 'index']);


Route::get('auth/{provider}', [SocialLoginController::class, 'redirectToProvider'])->name('social.login');
Route::get('auth/{provider}/callback', [SocialLoginController::class, 'handleProviderCallback']);

Route::post('/menus/store-menu-item', [MenuItemsController::class, 'storeMenuItem'])->name('admin.menus.store.item');

Route::controller(GameController::class)->middleware('trackPage')->group(function () {
    Route::get('/game/{slug}', 'index')->name('game');
    Route::get('/game/{slug}/play', 'play')->name('game.play');
    Route::get('/search', 'search')->name('search');
    Route::get('/category/{slug}', 'category')->name('category');
});

Route::controller(GameController::class)->prefix('admin')->middleware('auth')->group(function(){
    Route::post('/games/{id}/like', 'likeGame')->name('games.like');
    Route::post('/games/{id}/dislike', 'dislikeGame')->name('games.dislike');

});

Route::post('/set-theme', [BusinessSettingsController::class, 'setTheme'])->name('set.theme');

// Route::get('/dashboard', function () {
//     return view('dashboard');
// })->middleware(['auth', 'verified'])->name('dashboard');

Route::controller(DashboardController::class)->middleware('auth', 'verified', 'admin')->prefix('admin')->group(function(){
    Route::get('/dashboard', 'Dashboard')->name('dashboard');

    Route::get('/admin/dashboard/live-locations', 'getLiveLocations')->name('admin.dashboard.liveLocations');

    // routes/web.php
    Route::get('/admin/dashboard/country-data', 'getCountryData')->name('admin.dashboard.country-data');


    Route::post('/admin/games/add-dash/', 'AddDash')->name('admin.add.dash');
});

Route::get('/blogs', [BlogPostController::class, 'Blogs'])->name('blogs');

Route::get('/{slug}', [PagesController::class, 'UserPages'])->name('pages.userpages');

Route::get('/blog/{slug}', [BlogPostController::class, 'blogpost'])->name('blog.posts');


Route::middleware('auth')->group(function () {

    Route::controller(DynamicPopupsController::class)->prefix('admin')->middleware('admin')->group(function() {
        Route::get('/dynamic-popups', 'DynamicPopups')->name('dynamic.popups');
        Route::get('/dynamic-popups/create', 'AddPopup')->name('add.popup');
        Route::post('/dynamic-popups/store', 'StorePopup')->name('store.popup');
        Route::get('/dynamic-popups/edit/{id}', 'EditPopup')->name('edit.popup');
        Route::post('/dynamic-popups/update', 'UpdatePopup')->name('update.popup');
        Route::get('/dynamic-popups/delete/{id}', 'DeletePopup')->name('delete.popup');
        Route::post('/dynamic-popups/toggle-status', 'updateStatus')->name('admin.popups.updateStatus');
    });

    Route::controller(CategoryController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/categories', 'categories')->name('admin.categories');
        Route::get('/categories/create', 'create')->name('admin.categories.create');
        Route::post('/categories/store', 'store')->name('admin.categories.store');
        Route::post('/categories/toggle-status', 'toggleStatus')->name('admin.categories.toggleStatus');
        Route::post('/categories/toggle-status-homepage', 'toggleStatusHomepage')->name('admin.categories.toggleStatus-homepage');
        Route::get('/categories/edit/{id}', 'edit')->name('admin.categories.edit');
        Route::post('/categories/update', 'update')->name('admin.categories.update');
        Route::get('/categories/delete/{id}', 'delete')->name('admin.categories.delete');
    });

    // User Controller for users
    Route::controller(UserController::class)->group(function(){
        // User History and Liked games
        Route::get('/user/history', 'userHistory')->name('user.history');
        Route::get('/user/liked', 'userLikedGames')->name('user.liked');
        Route::get('/user/profile', 'UserProfile')->name('user.profile');
        Route::post('/user/profile/update', 'UserProfileUpdate')->name('user.profile.update');
    });


    Route::prefix('admin')->middleware('admin')->group(function ()  {
        Route::get('/menus', [MenusController::class, 'index'])->name('admin.menus.index');
        Route::get('/menus/create', [MenusController::class, 'create'])->name('admin.menus.create');
        Route::post('/menus', [MenusController::class, 'store'])->name('admin.menus.store');
        Route::get('/menus/{menu}/edit', [MenusController::class, 'edit'])->name('admin.menus.edit');
        Route::post('/menus/{menu}', [MenusController::class, 'update'])->name('admin.menus.update');
        Route::post('/menus/{menu}/delete', [MenusController::class, 'destroy'])->name('admin.menus.destroy');
        Route::post('/admin/menus/save-order', [MenusController::class, 'saveOrder'])->name('admin.menus.saveOrder');
    });

    Route::controller(ThemesController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/themes', 'index')->name('admin.themes');
        Route::post('/themes/activate', 'activate')->name('admin.themes.activate');
        Route::post('/themes/upload', 'upload')->name('admin.themes.upload');
        Route::post('/themes/delete', 'delete')->name('admin.themes.delete');
    });

    Route::post('/games/{id}/comment', [GameController::class, 'storeComment'])->name('games.comment')->middleware('auth');
    Route::post('/comments/{comment}/reply', [GameController::class, 'storeReply'])->name('games.reply');

    Route::controller(GameController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/games', 'games')->name('admin.games');
        Route::get('/games/featured', 'FeaturedGames')->name('admin.games.featured');
        Route::get('/games/disabled', 'DisabledGames')->name('admin.games.disabled');
        Route::get('/games/create', 'create')->name('admin.games.create');
        Route::post('/games/store', 'store')->name('admin.games.store');
        Route::post('/games/toggle-status', 'toggleStatus')->name('admin.games.toggleStatus');
        Route::get('/games/edit/{id}', 'edit')->name('admin.games.edit');
        Route::post('/games/update', 'update')->name('admin.games.update');
        Route::get('/games/delete/{id}', 'delete')->name('admin.games.delete');
        Route::post('/admin/games/add', 'addGame')->name('admin.games.add');
        Route::post('/admin/games/fetch', 'fetchGames')->name('admin.games.fetch');

    });

    Route::controller(AdminController::class)->prefix('admin')->group(function(){
        Route::post('/admin/game/api2', 'AdminAPI2Fetch')->name('admin.api2.fetch');
        Route::get('/feature/activation', 'FeatureActivation')->name('admin.feature.activation');
        Route::post('/update-force-https', 'updateForceHttps')->name('admin.update.force_https');
        Route::post('/settings/toggle-login', 'toggleLoginSetting')->name('settings.toggle.login');
        Route::post('/admin/social-settings', 'updateSocialSettings')->name('admin.social.login.settings.update');
    });

    Route::controller(UserController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/active-users', 'ActiveUsers')->name('admin.active.users');
        Route::get('/blocked-users', 'InactiveUsers')->name('admin.inactive.users');
        Route::get('/users/edit/{id}', 'edit')->name('admin.users.edit');
        Route::post('/users/update', 'update')->name('admin.users.update');
        Route::get('/users/delete/{id}', 'delete')->name('admin.users.delete');
        Route::get('/track-visit', 'trackVisit');
        Route::post('/user/toggle-status', 'UserToggleStatus')->name('admin.user.toggleStatus');
    });

    Route::controller(PagesController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/pages', 'pages')->name('admin.pages');
        Route::get('/pages/create', 'create')->name('admin.pages.create');
        Route::post('/pages/store', 'store')->name('admin.pages.store');
        Route::post('/pages/toggle-status', 'toggleStatus')->name('admin.pages.toggleStatus');
        Route::get('/pages/edit/{id}', 'edit')->name('admin.pages.edit');
        Route::post('/pages/update', 'update')->name('admin.pages.update');
        Route::get('/pages/delete/{id}', 'delete')->name('admin.pages.delete');
    });

    Route::controller(BlogCategoryController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/blog-categories', 'blogCategories')->name('admin.blog.categories');
        Route::get('/blog-categories/create', 'create')->name('admin.blog.categories.create');
        Route::post('/blog-categories/store', 'store')->name('admin.blog.categories.store');
        Route::post('/blog-categories/toggle-status', 'toggleStatus')->name('admin.blog.categories.toggleStatus');
        Route::get('/blog-categories/edit/{id}', 'edit')->name('admin.blog.categories.edit');
        Route::post('/blog-categories/update', 'update')->name('admin.blog.categories.update');
        Route::get('/blog-categories/delete/{id}', 'delete')->name('admin.blog.categories.delete');
    });

    Route::controller(BlogPostController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/blog-posts', 'blogPosts')->name('admin.blog.posts');
        Route::get('/blog-posts/create', 'create')->name('admin.blog.posts.create');
        Route::post('/blog-posts/store', 'store')->name('admin.blog.posts.store');
        Route::post('/blog-posts/toggle-status', 'toggleStatus')->name('admin.blog.posts.toggleStatus');
        Route::get('/blog-posts/edit/{id}', 'edit')->name('admin.blog.posts.edit');
        Route::post('/blog-posts/update', 'update')->name('admin.blog.posts.update');
        Route::get('/blog-posts/delete/{id}', 'delete')->name('admin.blog.posts.delete');
    });

    Route::get('/translations/{id}', [TranslationController::class, 'index'])->name('translations.index');
    Route::post('/translations', [TranslationController::class, 'store'])->name('translations.store');

    Route::controller(LanguagesController::class)->prefix('admin')->group(function(){
        Route::get('/languages', 'index')->name('admin.languages');
        Route::get('/create-language', 'CreateLanguage')->name('admin.create.language');
        Route::post('/store-language', 'storeLanguage')->name('admin.store.language');
        Route::get('/edit-language/{id}', 'editLanguage')->name('admin.edit.language');
        Route::post('/update-language', 'updateLanguage')->name('admin.update.language');
        Route::post('/delete-language/{id}', 'deleteLanguage')->name('admin.delete.language');
        Route::get('/fetch-language', 'fetchLanguage')->name('admin.fetch.language');
        Route::post('toggle-status', 'toggleStatus')->name('admin.languages.toggleStatus');
        Route::post('toggle-rtl', 'toggleRTL')->name('admin.languages.toggleRtl');
        Route::post('/store-default-language', 'StoreDefaultLanguage')->name('admin.store.default.language');
    });

    Route::controller(AdvertisementController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/advertisements', 'advertisements')->name('admin.advertisements');
        Route::get('/advertisements/create', 'create')->name('admin.advertisements.create');
        Route::post('/advertisements/store', 'store')->name('admin.advertisements.store');
        Route::post('/advertisements/toggle-status', 'toggleStatus')->name('admin.advertisements.toggleStatus');
        Route::get('/advertisements/edit/{id}', 'edit')->name('admin.advertisements.edit');
        Route::post('/advertisements/update', 'update')->name('admin.advertisements.update');
        Route::get('/advertisements/delete/{id}', 'delete')->name('admin.advertisements.delete');
    });

    Route::controller(BusinessSettingsController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/server-information', 'ServerInfo')->name('server.info');
        Route::get('/header-settings', 'HeaderSettings')->name('admin.header.settings');
        Route::post('/header-settings/update', 'UpdateHeaderSettings')->name('admin.header.settings.update');
        Route::get('/global-settings', 'GlobalSettings')->name('admin.global.settings');
        Route::post('/global-settings/update', 'UpdateGlobalSettings')->name('admin.global.settings.update');
        Route::post('/seo-settings-update', 'SEOSettingsUpdate')->name('admin.seo.settings.update');
        Route::post('/social-settings-update', 'SocialSettingsUpdate')->name('admin.social.settings.update');
        Route::get('/mobile-app-settings', 'MobileAppSettings')->name('admin.mobile.app.settings');
        Route::get('/smtp-settings', 'SmtpSettings')->name('admin.smtp.settings');
        Route::post('/smtp-settings-update', 'SmtpSettingsUpdate')->name('admin.smtp.settings.update');
        Route::post('/admin/smtp-settings-test', 'sendTestEmail')->name('admin.smtp.settings.test');
        Route::get('/newsletters', 'NewsLetters')->name('admin.newsletters');
        Route::post('/admin/newsletter/send', 'sendNewletter')->name('admin.newsletter.send');
    });

    Route::controller(MenuItemsController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('menus/create-item/{menu}', 'createMenuItem')->name('admin.menus.createItem');

        Route::get('menus/item/{item}/edit', 'editMenuItem')->name('admin.menus.editItem');
        Route::post('menus/item/update', 'updateMenuItem')->name('admin.menus.updateItem');
        Route::get('menus/item/{item}', 'destroyMenuItem')->name('admin.menus.destroyItem');
    });

    Route::controller(SubscriberController::class)->prefix('admin')->middleware('admin')->group(function(){
        Route::get('/subscribers', 'index')->name('admin.subscribers');
        Route::get('/subscribers/export', 'export')->name('admin.subscribers.export');
    });

    Route::controller(ProfileController::class)->prefix('admin')->group(function(){
        Route::get('/profile', 'edit')->name('profile.edit');
        Route::patch('/profile', 'update')->name('profile.update');
        Route::delete('/profile', 'destroy')->name('profile.destroy');
        Route::get('/update-password', 'updatePassword')->name('profile.updatePassword');
    });
});


Route::post('/subscriber-newsletter', [SubscriberController::class, 'store'])->name('subscriber.newsletter');

Route::get('/proxy-game/{slug}', [GameController::class, 'proxyGame'])->name('proxy.game');

require __DIR__.'/auth.php';
