<?php
    // Fetch the main menu value from BusinessSettings
    $mainMenu = App\Models\BusinessSettings::where('key', 'main_menu')->first();
    if ($mainMenu && $mainMenu->value) {
        // Fetch the menu using the value from the main menu settings
        $selectedMenu = App\Models\Menus::where('id', $mainMenu->value)->first();
    }
    $menuItems = App\Models\MenuItems::where('menu_id', $selectedMenu->id)->orderBy('order', 'asc')->get();

    $loginEnabled = App\Models\BusinessSettings::where('key', 'header_login')->first()->value;
    $searchEnabled = App\Models\BusinessSettings::where('key', 'header_search')->first()->value;
    $logo = App\Models\BusinessSettings::where('key', 'website_logo')->first()->value;
    $languages = \App\Models\Languages::where('status', 1)->get();
    $settings = \App\Models\BusinessSettings::pluck('value', 'key')->toArray();
?>

<nav class="navbar navbar-expand-lg navbar-gaming">
    <div class="container-fluid">
        <a class="navbar-brand" href="<?php echo e(route('home')); ?>">
            <img src="<?php echo e(asset('images/logos/'.$logo)); ?>" alt="HTML Games">
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="offcanvas" data-bs-target="#offcanvasNavbar"
            aria-controls="offcanvasNavbar">
            <span class="navbar-toggler-icon"></span>
        </button>

        <div class="offcanvas offcanvas-start text-bg-dark" tabindex="-1" id="offcanvasNavbar"
            aria-labelledby="offcanvasNavbarLabel">
            <div class="offcanvas-header">
                <h5 class="offcanvas-title" id="offcanvasNavbarLabel"><?php echo e($settings['website_name']); ?></h5>
                <button type="button" class="btn-close btn-close-white" data-bs-dismiss="offcanvas"
                    aria-label="Close"></button>
            </div>

            <div class="offcanvas-body">
                <ul class="navbar-nav me-auto m-1 mt-2">
                    <?php $__currentLoopData = $menuItems; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $items): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <li class="nav-item">
                            <a class="nav-link" href="<?php echo e($items->url); ?>">
                                <i class="bi bi-controller"></i>
                                <span class="ml-3"><?php echo e(translate($items->title)); ?></span>
                            </a>
                        </li>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </ul>

                <?php if($searchEnabled == 1): ?>
                    <!-- Search bar -->
                    <form class="d-flex mt-2 m-1 search-box" action="<?php echo e(route('search')); ?>" method="GET">
                        <input class="form-control search-bar me-2" name="search" type="search" placeholder="<?php echo e(translate('Search games...')); ?>" aria-label="Search">
                        <button class="btn-search" type="submit"></button>
                    </form>
                <?php endif; ?>
                <!-- User Menu Dropdown (after the search bar) -->
                <div class="d-flex">
                    <?php if($loginEnabled == 1): ?>
                        <?php if(auth()->guard()->check()): ?>
                            <div class="dropdown ms-1 m-1 mt-2 text-center">
                                <button class="btn btn-secondary dropdown-toggle" type="button" id="userMenuDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                                    <img src="<?php echo e(Auth::user()->image ? asset('images/user/' . Auth::user()->image) : asset('images/default-avatar.avif')); ?>" width="30" height="30" class="rounded-circle ms-2">
                                    
                                </button>


                                <ul class="dropdown-menu" aria-labelledby="userMenuDropdown">
                                    <li><a class="dropdown-item" href="<?php echo e(route('user.profile')); ?>"><i class="bi bi-user"></i><?php echo e(translate('Profile')); ?></a></li>
                                    <li><a class="dropdown-item" href="<?php echo e(route('user.liked')); ?>"><?php echo e(translate('Liked Games')); ?></a></li>
                                    <li><a class="dropdown-item" href="<?php echo e(route('user.history')); ?>"><?php echo e(translate('History')); ?></a></li>
                                    <li><hr class="dropdown-divider"></li>
                                    <li>
                                        <a class="dropdown-item" href="<?php echo e(route('logout')); ?>"
                                            onclick="event.preventDefault(); document.getElementById('logout-form').submit();">
                                            <?php echo e(translate('Logout')); ?>

                                        </a>
                                        <form id="logout-form" action="<?php echo e(route('logout')); ?>" method="POST" class="d-none">
                                            <?php echo csrf_field(); ?>
                                        </form>
                                    </li>
                                </ul>
                            </div>
                        <?php endif; ?>
                    <?php endif; ?>

                    <!-- Show Login button if not logged in -->
                    <?php if(auth()->guard()->guest()): ?>
                        <a href="<?php echo e(route('user.login')); ?>" style="font-weight: bold; text-transform:uppercase;" class="btn btn-primary m-1 mt-2 login-btn"><?php echo e(translate('Login')); ?></a>
                    <?php endif; ?>

                    <div class="dropdown ms-1 m-1 mt-2 text-center">
                        <button class="btn btn-secondary dropdown-toggle" type="button" id="userMenuDropdown" data-bs-toggle="dropdown" aria-expanded="false">
                            <img src="<?php echo e(asset('frontend/flags/' . currentLanguage()['flag'])); ?>" width="30" height="30" class="rounded-circle ms-2">
                            <?php echo e(currentLanguage()['name']); ?>

                        </button>
                        <ul class="dropdown-menu" aria-labelledby="userMenuDropdown">
                            <?php $__currentLoopData = $languages; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $lang): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                <li>
                                    <a class="dropdown-item" href="<?php echo e(route('change.language', $lang->code)); ?>">
                                        <img src="<?php echo e(asset('frontend/flags/' . $lang->app_lang_code . '.svg')); ?>" width="20" height="20" class="me-2">
                                        <?php echo e($lang->name); ?>

                                    </a>
                                </li>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</nav>
<?php /**PATH /home/filaoxuw/toktuk.com/resources/views/frontend/partials/_header.blade.php ENDPATH**/ ?>