<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules\Password;

class PasswordController extends Controller
{
    /**
     * Update the user's password.
     */
    public function update(Request $request): RedirectResponse
    {
        // Validate input
        $validated = $request->validate([
            'current_password' => ['required', 'current_password'], // Check current password
            'password' => ['required', 'confirmed', Password::defaults()], // New password and confirmation
        ]);

        // Update the user's password
        $user = $request->user();

        // Make sure the new password is different from the old one
        if (Hash::check($validated['current_password'], $user->password)) {
            $user->update([
                'password' => Hash::make($validated['password']),
            ]);
        } else {
            return back()->withErrors(['current_password' => 'The current password is incorrect.']);
        }

        return back()->with('status', 'Password updated successfully!');
    }

}
